@@ -627,7 +627,7 @@ add_one_compatible_uri (const char *uri, int x, int y, int w, int h, gpointer da
 	 * gnome-libs function or nothing will be able to understand
 	 * it.
 	 */
-	if (!eel_istr_has_prefix (uri, "file:")) {
+	if (!g_str_has_prefix (uri, "file:")) {
 		g_string_append (result, uri);
 		g_string_append (result, "\r\n");
 	} else {
@@ -916,7 +916,7 @@ nautilus_drag_autoscroll_start (NautilusDragInfo *drag_info,
 	if (nautilus_drag_autoscroll_in_scroll_region (widget)) {
 		if (drag_info->auto_scroll_timeout_id == 0) {
 			drag_info->waiting_to_autoscroll = TRUE;
-			drag_info->start_auto_scroll_in = eel_get_system_time() 
+			drag_info->start_auto_scroll_in = g_get_monotonic_time () 
 				+ AUTOSCROLL_INITIAL_DELAY;
 			
 			drag_info->auto_scroll_timeout_id = g_timeout_add
