@@ -53,7 +53,6 @@
 static void update_xdg_dir_cache (void);
 static void schedule_user_dirs_changed (void);
 static void desktop_dir_changed (void);
-static GFile *nautilus_find_file_insensitive_next (GFile *parent, const gchar *name);
 
 char *
 nautilus_compute_title_for_location (GFile *location)
@@ -116,27 +115,6 @@ nautilus_get_user_directory (void)
 	return user_directory;
 }
 
-/**
- * nautilus_get_accel_map_file:
- * 
- * Get the path for the filename containing nautilus accelerator map.
- * The filename need not exist.
- *
- * Return value: the filename path, or NULL if the home directory could not be found
- **/
-char *
-nautilus_get_accel_map_file (void)
-{
-	const gchar *override;
-
-	override = g_getenv ("GNOME22_USER_DIR");
-
-	if (override) {
-		return g_build_filename (override, "accels/nautilus", NULL);
-	} else {
-		return g_build_filename (g_get_home_dir (), ".gnome2/accels/nautilus", NULL);
-	}
-}
 
 typedef struct {
 	char *type;
@@ -437,11 +415,7 @@ nautilus_get_xdg_dir (const char *type)
 static char *
 get_desktop_path (void)
 {
-	if (g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR)) {
-		return g_strdup (g_get_home_dir());
-	} else {
-		return nautilus_get_xdg_dir ("DESKTOP");
-	}
+	return nautilus_get_xdg_dir ("DESKTOP");
 }
 
 /**
@@ -459,17 +433,15 @@ nautilus_get_desktop_directory (void)
 	desktop_directory = get_desktop_path ();
 
 	/* Don't try to create a home directory */
-	if (!g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR)) {
-		if (!g_file_test (desktop_directory, G_FILE_TEST_EXISTS)) {
-			g_mkdir (desktop_directory, DEFAULT_DESKTOP_DIRECTORY_MODE);
-			/* FIXME bugzilla.gnome.org 41286: 
-			 * How should we handle the case where this mkdir fails? 
-			 * Note that nautilus_application_startup will refuse to launch if this 
-			 * directory doesn't get created, so that case is OK. But the directory 
-			 * could be deleted after Nautilus was launched, and perhaps
-			 * there is some bad side-effect of not handling that case.
-			 */
-		}
+	if (!g_file_test (desktop_directory, G_FILE_TEST_EXISTS)) {
+		g_mkdir (desktop_directory, DEFAULT_DESKTOP_DIRECTORY_MODE);
+		/* FIXME bugzilla.gnome.org 41286: 
+		 * How should we handle the case where this mkdir fails? 
+		 * Note that nautilus_application_startup will refuse to launch if this 
+		 * directory doesn't get created, so that case is OK. But the directory 
+		 * could be deleted after Nautilus was launched, and perhaps
+		 * there is some bad side-effect of not handling that case.
+		 */
 	}
 
 	return desktop_directory;
@@ -488,7 +460,6 @@ nautilus_get_desktop_location (void)
 	return res;
 }
 
-
 /**
  * nautilus_get_desktop_directory_uri:
  * 
@@ -509,19 +480,6 @@ nautilus_get_desktop_directory_uri (void)
 	return desktop_uri;
 }
 
-char *
-nautilus_get_desktop_directory_uri_no_create (void)
-{
-	char *desktop_path;
-	char *desktop_uri;
-	
-	desktop_path = get_desktop_path ();
-	desktop_uri = g_filename_to_uri (desktop_path, NULL, NULL);
-	g_free (desktop_path);
-
-	return desktop_uri;
-}
-
 char *
 nautilus_get_home_directory_uri (void)
 {
@@ -590,7 +548,6 @@ nautilus_get_searches_directory (void)
 static GFile *desktop_dir = NULL;
 static GFile *desktop_dir_dir = NULL;
 static char *desktop_dir_filename = NULL;
-static gboolean desktop_dir_changed_callback_installed = FALSE;
 
 
 static void
@@ -608,12 +565,6 @@ desktop_dir_changed (void)
 	desktop_dir_filename = NULL;
 }
 
-static void
-desktop_dir_changed_callback (gpointer callback_data)
-{
-	desktop_dir_changed ();
-}
-
 static void
 update_desktop_dir (void)
 {
@@ -679,13 +630,6 @@ nautilus_is_desktop_directory_file (GFile *dir,
 				    const char *file)
 {
 
-	if (!desktop_dir_changed_callback_installed) {
-		g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
-					  G_CALLBACK(desktop_dir_changed_callback),
-					  NULL);
-		desktop_dir_changed_callback_installed = TRUE;
-	}
-
 	if (desktop_dir == NULL) {
 		update_desktop_dir ();
 	}
@@ -698,13 +642,6 @@ gboolean
 nautilus_is_desktop_directory (GFile *dir)
 {
 
-	if (!desktop_dir_changed_callback_installed) {
-		g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
-					  G_CALLBACK(desktop_dir_changed_callback),
-					  NULL);
-		desktop_dir_changed_callback_installed = TRUE;
-	}
-
 	if (desktop_dir == NULL) {
 		update_desktop_dir ();
 	}
@@ -712,45 +649,6 @@ nautilus_is_desktop_directory (GFile *dir)
 	return g_file_equal (dir, desktop_dir);
 }
 
-
-/**
- * nautilus_get_gmc_desktop_directory:
- * 
- * Get the path for the directory containing the legacy gmc desktop.
- *
- * Return value: the directory path.
- **/
-char *
-nautilus_get_gmc_desktop_directory (void)
-{
-	return g_build_filename (g_get_home_dir (), LEGACY_DESKTOP_DIRECTORY_NAME, NULL);
-}
-
-char *
-nautilus_get_data_file_path (const char *partial_path)
-{
-	char *path;
-	char *user_directory;
-
-	/* first try the user's home directory */
-	user_directory = nautilus_get_user_directory ();
-	path = g_build_filename (user_directory, partial_path, NULL);
-	g_free (user_directory);
-	if (g_file_test (path, G_FILE_TEST_EXISTS)) {
-		return path;
-	}
-	g_free (path);
-	
-	/* next try the shared directory */
-	path = g_build_filename (NAUTILUS_DATADIR, partial_path, NULL);
-	if (g_file_test (path, G_FILE_TEST_EXISTS)) {
-		return path;
-	}
-	g_free (path);
-
-	return NULL;
-}
-
 char *
 nautilus_ensure_unique_file_name (const char *directory_uri,
 				  const char *base_name,
@@ -799,26 +697,6 @@ nautilus_ensure_unique_file_name (const char *directory_uri,
 	return res;
 }
 
-char *
-nautilus_unique_temporary_file_name (void)
-{
-	const char *prefix = "/tmp/nautilus-temp-file";
-	char *file_name;
-	int fd;
-
-	file_name = g_strdup_printf ("%sXXXXXX", prefix);
-
-	fd = g_mkstemp (file_name); 
-	if (fd == -1) {
-		g_free (file_name);
-		file_name = NULL;
-	} else {
-		close (fd);
-	}
-	
-	return file_name;
-}
-
 GFile *
 nautilus_find_existing_uri_in_hierarchy (GFile *location)
 {
@@ -844,117 +722,6 @@ nautilus_find_existing_uri_in_hierarchy (GFile *location)
 	return location;
 }
 
-/**
- * nautilus_find_file_insensitive
- * 
- * Attempt to find a file case-insentively. If the path can be found, the
- * returned file maps directly to it. Otherwise, a file using the
- * originally-cased path is returned. This function performs might perform
- * I/O.
- * 
- * Return value: a #GFile to a child specified by @name.
- **/
-GFile *
-nautilus_find_file_insensitive (GFile *parent, const gchar *name)
-{
-	gchar **split_path;
-	gchar *component;
-	GFile *file, *next;
-	gint i;
-	
-	split_path = g_strsplit (name, G_DIR_SEPARATOR_S, -1);
-	
-	file = g_object_ref (parent);
-	
-	for (i = 0; (component = split_path[i]) != NULL; i++) {
-		if (!(next = nautilus_find_file_insensitive_next (file,
-		                                                  component))) {
-			/* File does not exist */
-			g_object_unref (file);
-			file = NULL;
-			break;
-		}
-		g_object_unref (file);
-		file = next;
-	}
-	g_strfreev (split_path);
-	
-	if (file) {
-		return file;
-	}
-	return g_file_get_child (parent, name);
-}
-
-static GFile *
-nautilus_find_file_insensitive_next (GFile *parent, const gchar *name)
-{
-	GFileEnumerator *children;
-	GFileInfo *info;
-	gboolean use_utf8, found;
-	char *filename, *case_folded_name, *utf8_collation_key, *ascii_collation_key, *child_key;
-	GFile *file;
-	const char *child_name, *compare_key;
-
-	/* First check the given version */
-	file = g_file_get_child (parent, name);
-	if (g_file_query_exists (file, NULL)) {
-		return file;
-	}
-	g_object_unref (file);
-	
-	ascii_collation_key = g_ascii_strdown (name, -1);
-	use_utf8 = g_utf8_validate (name, -1, NULL);
-	utf8_collation_key = NULL;	
-	if (use_utf8) {
-		case_folded_name = g_utf8_casefold (name, -1);
-		utf8_collation_key = g_utf8_collate_key (case_folded_name, -1);
-		g_free (case_folded_name);
-	}
-
-	/* Enumerate and compare insensitive */
-	filename = NULL;
-	children = g_file_enumerate_children (parent,
-	                                      G_FILE_ATTRIBUTE_STANDARD_NAME,
-	                                      0, NULL, NULL);
-	if (children != NULL) {
-		while ((info = g_file_enumerator_next_file (children, NULL, NULL))) {
-			child_name = g_file_info_get_name (info);
-			
-			if (use_utf8 && g_utf8_validate (child_name, -1, NULL)) {
-				gchar *case_folded;
-				
-				case_folded = g_utf8_casefold (child_name, -1);
-				child_key = g_utf8_collate_key (case_folded, -1);
-				g_free (case_folded);
-				compare_key = utf8_collation_key;
-			} else {
-				child_key = g_ascii_strdown (child_name, -1);
-				compare_key = ascii_collation_key;
-			}
-			
-			found = strcmp (child_key, compare_key) == 0;
-			g_free (child_key);
-			if (found) {
-				filename = g_strdup (child_name);
-				break;
-			}
-		}
-		g_file_enumerator_close (children, NULL, NULL);
-		g_object_unref (children);
-	}
-	
-	g_free (ascii_collation_key);
-	g_free (utf8_collation_key);
-	
-	if (filename) {
-		file = g_file_get_child (parent, filename);
-		g_free (filename);
-		return file;
-	}
-	
-	return NULL;
-}
-
 gboolean
 nautilus_is_file_roller_installed (void)
 {
@@ -971,143 +738,13 @@ nautilus_is_file_roller_installed (void)
 	return installed > 0 ? TRUE : FALSE;
 }
 
-#define GSM_NAME  "org.gnome.SessionManager"
-#define GSM_PATH "/org/gnome/SessionManager"
-#define GSM_INTERFACE "org.gnome.SessionManager"
-
-/* The following values come from
- * http://www.gnome.org/~mccann/gnome-session/docs/gnome-session.html#org.gnome.SessionManager.Inhibit 
- */
-#define INHIBIT_LOGOUT (1U)
-#define INHIBIT_SUSPEND (4U)
-
-static GDBusConnection *
-get_dbus_connection (void)
-{
-	static GDBusConnection *conn = NULL;
-
-	if (conn == NULL) {
-		GError *error = NULL;
-
-	        conn = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, &error);
-
-		if (conn == NULL) {
-	                g_warning ("Could not connect to session bus: %s", error->message);
-			g_error_free (error);
-		}
-	}
-
-	return conn;
-}
-
-/**
- * nautilus_inhibit_power_manager:
- * @message: a human readable message for the reason why power management
- *       is being suspended.
- *
- * Inhibits the power manager from logging out or suspending the machine
- * (e.g. whenever Nautilus is doing file operations).
- *
- * Returns: an integer cookie, which must be passed to
- *    nautilus_uninhibit_power_manager() to resume
- *    normal power management.
- */
-int
-nautilus_inhibit_power_manager (const char *message)
-{
-	GDBusConnection *connection;
-	GVariant *result;
-	GError *error = NULL;
-	guint cookie = 0;
-
-	g_return_val_if_fail (message != NULL, -1);
-
-        connection = get_dbus_connection ();
-
-        if (connection == NULL) {
-                return -1;
-        }
-
-	result = g_dbus_connection_call_sync (connection,
-					      GSM_NAME,
-					      GSM_PATH,
-					      GSM_INTERFACE,
-					      "Inhibit",
-					      g_variant_new ("(susu)",
-							     "Nautilus",
-							     (guint) 0,
-							     message,
-							     (guint) (INHIBIT_LOGOUT | INHIBIT_SUSPEND)),
-					      G_VARIANT_TYPE ("(u)"),
-					      G_DBUS_CALL_FLAGS_NO_AUTO_START,
-					      -1,
-					      NULL,
-					      &error);
-
-	if (error != NULL) {
-		g_warning ("Could not inhibit power management: %s", error->message);
-		g_error_free (error);
-		return -1;
-	}
-
-	g_variant_get (result, "(u)", &cookie);
-	g_variant_unref (result);
-
-	return (int) cookie;
-}
-
-/**
- * nautilus_uninhibit_power_manager:
- * @cookie: the cookie value returned by nautilus_inhibit_power_manager()
- *
- * Uninhibits power management. This function must be called after the task
- * which inhibited power management has finished, or the system will not
- * return to normal power management.
- */
-void
-nautilus_uninhibit_power_manager (gint cookie)
-{
-	GDBusConnection *connection;
-	GVariant *result;
-	GError *error = NULL;
-
-	g_return_if_fail (cookie > 0);
-
-	connection = get_dbus_connection ();
-
-	if (connection == NULL) {
-		return;
-	}
-
-	result = g_dbus_connection_call_sync (connection,
-					      GSM_NAME,
-					      GSM_PATH,
-					      GSM_INTERFACE,
-					      "Uninhibit",
-					      g_variant_new ("(u)", (guint) cookie),
-					      NULL,
-					      G_DBUS_CALL_FLAGS_NO_AUTO_START,
-					      -1,
-					      NULL,
-					      &error);
-
-	if (result == NULL) {
-		g_warning ("Could not uninhibit power management: %s", error->message);
-		g_error_free (error);
-		return;
-	}
-
-	g_variant_unref (result);
-}
-
-/* Returns TRUE if the file is in XDG_DATA_DIRS or
-   in "~/.gnome2/". This is used for deciding
-   if a desktop file is "trusted" based on the path */
+/* Returns TRUE if the file is in XDG_DATA_DIRS. This is used for
+   deciding if a desktop file is "trusted" based on the path */
 gboolean
 nautilus_is_in_system_dir (GFile *file)
 {
 	const char * const * data_dirs; 
-	char *path, *gnome2;
+	char *path;
 	int i;
 	gboolean res;
 	
@@ -1128,16 +765,6 @@ nautilus_is_in_system_dir (GFile *file)
 		
 	}
 
-	if (!res) {
-		/* Panel desktop files are here, trust them */
-		gnome2 = g_build_filename (g_get_home_dir (), ".gnome2", NULL);
-		if (g_str_has_prefix (path, gnome2)) {
-			res = TRUE;
-		}
-		g_free (gnome2);
-	}
-	g_free (path);
-	
 	return res;
 }
 
