@@ -587,8 +587,6 @@ nautilus_icon_container_selection_items_local (NautilusIconContainer *container,
 	/* must have at least one item */
 	g_assert (items);
 
-	result = FALSE;
-
 	/* get the URI associated with the container */
 	container_uri_string = get_container_uri (container);
 	
@@ -702,7 +700,7 @@ auto_scroll_timeout_callback (gpointer data)
 	container = NAUTILUS_ICON_CONTAINER (widget);
 
 	if (container->details->dnd_info->drag_info.waiting_to_autoscroll
-	    && container->details->dnd_info->drag_info.start_auto_scroll_in > eel_get_system_time()) {
+	    && container->details->dnd_info->drag_info.start_auto_scroll_in > g_get_monotonic_time ()) {
 		/* not yet */
 		return TRUE;
 	}
@@ -1019,7 +1017,7 @@ selection_is_image_file (GList *selection_list)
 		mime_type = g_file_info_get_content_type (info);
 	}
 
-	result = eel_istr_has_prefix (mime_type, "image/");
+	result = g_str_has_prefix (mime_type, "image/");
 
 	if (info) {
 		g_object_unref (info);
