@@ -111,26 +111,6 @@ nautilus_action_from_menu_item (NautilusMenuItem *item)
 	return action;
 }
 
-gboolean
-nautilus_event_should_open_in_new_tab (void)
-{
-	GdkEvent *event;
-
-	event = gtk_get_current_event ();
-
-	if (event == NULL) {
-		return FALSE;
-	}
-
-	if (event->type == GDK_BUTTON_PRESS || event->type == GDK_BUTTON_RELEASE) {
-		return event->button.button == 2;
-	}
-
-	gdk_event_free (event);
-
-	return FALSE;
-}
-
 GdkPixbuf *
 nautilus_ui_get_menu_icon (const char *icon_name)
 {
