@@ -34,8 +34,10 @@
 #include "nautilus-empty-view.h"
 #endif /* ENABLE_EMPTY_VIEW */
 
+#include "nautilus-connect-server-dialog.h"
 #include "nautilus-desktop-icon-view.h"
 #include "nautilus-desktop-window.h"
+#include "nautilus-file-management-properties.h"
 #include "nautilus-freedesktop-dbus.h"
 #include "nautilus-icon-view.h"
 #include "nautilus-image-properties-page.h"
@@ -59,7 +61,6 @@
 #include <libnautilus-private/nautilus-module.h>
 #include <libnautilus-private/nautilus-signaller.h>
 #include <libnautilus-private/nautilus-ui-utilities.h>
-#include <libnautilus-private/nautilus-undo-manager.h>
 #include <libnautilus-extension/nautilus-menu-provider.h>
 
 #define DEBUG_FLAG NAUTILUS_DEBUG_APPLICATION
@@ -83,16 +84,9 @@
 
 #define START_STATE_CONFIG "start-state"
 
-#define NAUTILUS_ACCEL_MAP_SAVE_DELAY 30
-
-static NautilusApplication *singleton = NULL;
-
 /* Keeps track of all the desktop windows. */
 static GList *nautilus_application_desktop_windows;
 
-/* The saving of the accelerator map was requested  */
-static gboolean save_of_accel_map_requested = FALSE;
-
 static void     desktop_changed_callback          (gpointer                  user_data);
 static void     mount_removed_callback            (GVolumeMonitor            *monitor,
 						   GMount                    *mount,
@@ -400,7 +394,8 @@ nautilus_application_create_desktop_windows (NautilusApplication *application)
 		
 		selection_widget = get_desktop_manager_selection (display, i);
 		if (selection_widget != NULL) {
-			window = nautilus_desktop_window_new (gdk_display_get_screen (display, i));
+			window = nautilus_desktop_window_new (GTK_APPLICATION (application),
+							      gdk_display_get_screen (display, i));
 
 			g_signal_connect (selection_widget, "selection_clear_event",
 					  G_CALLBACK (selection_clear_event_cb), window);
@@ -416,9 +411,6 @@ nautilus_application_create_desktop_windows (NautilusApplication *application)
 
 			nautilus_application_desktop_windows =
 				g_list_prepend (nautilus_application_desktop_windows, window);
-
-			gtk_application_add_window (GTK_APPLICATION (application),
-						    GTK_WINDOW (window));
 		}
 	}
 }
@@ -442,63 +434,6 @@ nautilus_application_close_desktop (void)
 	}
 }
 
-void
-nautilus_application_close_all_windows (NautilusApplication *self)
-{
-	GList *list_copy;
-	GList *l;
-	
-	list_copy = g_list_copy (gtk_application_get_windows (GTK_APPLICATION (self)));
-	for (l = list_copy; l != NULL; l = l->next) {
-		NautilusWindow *window;
-		
-		window = NAUTILUS_WINDOW (l->data);
-		nautilus_window_close (window);
-	}
-	g_list_free (list_copy);
-}
-
-static gboolean
-nautilus_window_delete_event_callback (GtkWidget *widget,
-				       GdkEvent *event,
-				       gpointer user_data)
-{
-	NautilusWindow *window;
-
-	window = NAUTILUS_WINDOW (widget);
-	nautilus_window_close (window);
-
-	return TRUE;
-}				       
-
-
-static NautilusWindow *
-create_window (NautilusApplication *application,
-	       GdkScreen *screen)
-{
-	NautilusWindow *window;
-	
-	g_return_val_if_fail (NAUTILUS_IS_APPLICATION (application), NULL);
-	
-	window = g_object_new (NAUTILUS_TYPE_WINDOW,
-			       "screen", screen,
-			       NULL);
-
-	g_signal_connect_data (window, "delete_event",
-			       G_CALLBACK (nautilus_window_delete_event_callback), NULL, NULL,
-			       G_CONNECT_AFTER);
-
-	gtk_application_add_window (GTK_APPLICATION (application),
-				    GTK_WINDOW (window));
-
-	/* Do not yet show the window. It will be shown later on if it can
-	 * successfully display its initial URI. Otherwise it will be destroyed
-	 * without ever having seen the light of day.
-	 */
-
-	return window;
-}
-
 static gboolean
 another_navigation_window_already_showing (NautilusApplication *application,
 					   NautilusWindow *the_window)
@@ -525,7 +460,7 @@ nautilus_application_create_window (NautilusApplication *application,
 
 	g_return_val_if_fail (NAUTILUS_IS_APPLICATION (application), NULL);
 
-	window = create_window (application, screen);
+	window = nautilus_window_new (GTK_APPLICATION (application), screen);
 
 	maximized = g_settings_get_boolean
 		(nautilus_window_state, NAUTILUS_WINDOW_STATE_MAXIMIZED);
@@ -571,16 +506,6 @@ desktop_changed_callback (gpointer user_data)
 	}
 }
 
-static gboolean
-window_can_be_closed (NautilusWindow *window)
-{
-	if (!NAUTILUS_IS_DESKTOP_WINDOW (window)) {
-		return TRUE;
-	}
-	
-	return FALSE;
-}
-
 static void
 mount_added_callback (GVolumeMonitor *monitor,
 		      GMount *mount,
@@ -638,7 +563,7 @@ mount_removed_callback (GVolumeMonitor *monitor,
 	/* Construct a list of windows to be closed. Do not add the non-closable windows to the list. */
 	for (node = window_list; node != NULL; node = node->next) {
 		window = NAUTILUS_WINDOW (node->data);
-		if (window != NULL && window_can_be_closed (window)) {
+		if (window != NULL && !NAUTILUS_IS_DESKTOP_WINDOW (window)) {
 			GList *l;
 			GList *lp;
 
@@ -671,7 +596,7 @@ mount_removed_callback (GVolumeMonitor *monitor,
 			nautilus_window_pane_slot_close (slot->pane, slot);
 		} else {
 			computer = g_file_new_for_path (g_get_home_dir ());
-			nautilus_window_slot_go_to (slot, computer, FALSE);
+			nautilus_window_slot_open_location (slot, computer, 0);
 			g_object_unref(computer);
 		}
 	}
@@ -744,10 +669,8 @@ nautilus_application_open_location (NautilusApplication *application,
 		sel_list = g_list_prepend (sel_list, nautilus_file_get (selection));
 	}
 
-	nautilus_window_slot_open_location (nautilus_window_get_active_slot (window),
-					    location,
-					    0,
-					    sel_list);
+	nautilus_window_slot_open_location_full (nautilus_window_get_active_slot (window), location,
+						 0, sel_list, NULL, NULL);
 
 	if (sel_list != NULL) {
 		nautilus_file_list_free (sel_list);
@@ -769,43 +692,171 @@ nautilus_application_open (GApplication *app,
 		      self->priv->geometry);
 }
 
-static GObject *
-nautilus_application_constructor (GType type,
-				  guint n_construct_params,
-				  GObjectConstructParam *construct_params)
+static GtkWindow *
+get_focus_window (GtkApplication *application)
 {
-        GObject *retval;
+	GList *windows;
+	GtkWindow *window = NULL;
 
-        if (singleton != NULL) {
-                return G_OBJECT (singleton);
-        }
+	/* the windows are ordered with the last focused first */
+	windows = gtk_application_get_windows (application);
 
-        retval = G_OBJECT_CLASS (nautilus_application_parent_class)->constructor
-                (type, n_construct_params, construct_params);
+	if (windows != NULL) {
+		window = g_list_nth_data (windows, 0);
+	}
 
-        singleton = NAUTILUS_APPLICATION (retval);
-        g_object_add_weak_pointer (retval, (gpointer) &singleton);
+	return window;
+}
 
-        return retval;
+static void
+action_new_window (GSimpleAction *action,
+		   GVariant *parameter,
+		   gpointer user_data)
+{
+	GtkApplication *application = user_data;
+	NautilusWindow *window;
+	GtkWindow *cur_window;
+
+	cur_window = get_focus_window (application);
+	window = nautilus_application_create_window (NAUTILUS_APPLICATION (application),
+						     cur_window ?
+						     gtk_window_get_screen (cur_window) :
+						     gdk_screen_get_default ());
+
+	nautilus_window_slot_go_home (nautilus_window_get_active_slot (window), 0);
+}
+
+static void
+action_connect_to_server (GSimpleAction *action,
+			  GVariant *parameter,
+			  gpointer user_data)
+{
+	GtkApplication *application = user_data;
+	GtkWidget *dialog;
+
+	dialog = nautilus_connect_server_dialog_new (NAUTILUS_WINDOW (get_focus_window (application)));
+	gtk_widget_show (dialog);
+}
+
+static void
+action_preferences (GSimpleAction *action,
+		    GVariant *parameter,
+		    gpointer user_data)
+{
+	GtkApplication *application = user_data;
+	nautilus_file_management_properties_dialog_show (get_focus_window (application));
+}
+
+static void
+action_about (GSimpleAction *action,
+	      GVariant *parameter,
+	      gpointer user_data)
+{
+	GtkApplication *application = user_data;
+
+	nautilus_window_show_about_dialog (NAUTILUS_WINDOW (get_focus_window (application)));
+}
+
+static void
+action_help (GSimpleAction *action,
+	     GVariant *parameter,
+	     gpointer user_data)
+{
+	GtkWindow *window;
+	GtkWidget *dialog;
+	GtkApplication *application = user_data;
+	GError *error = NULL;
+
+	window = get_focus_window (application);	
+	gtk_show_uri (window ? 
+		      gtk_window_get_screen (GTK_WINDOW (window)) :
+		      gdk_screen_get_default (),
+		      "help:gnome-help/files",
+		      gtk_get_current_event_time (), &error);
+
+	if (error) {
+		dialog = gtk_message_dialog_new (window ? GTK_WINDOW (window) : NULL,
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_OK,
+						 _("There was an error displaying help: \n%s"),
+						 error->message);
+		g_signal_connect (G_OBJECT (dialog), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+
+		gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+		gtk_widget_show (dialog);
+		g_error_free (error);
+	}
+}
+
+static void
+action_kill (GSimpleAction *action,
+	     GVariant *parameter,
+	     gpointer user_data)
+{
+	GtkApplication *application = user_data;
+	GList *windows;
+
+	/* this will also destroy the desktop windows */
+	windows = gtk_application_get_windows (application);
+	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
+}
+
+static void
+action_quit (GSimpleAction *action,
+	     GVariant *parameter,
+	     gpointer user_data)
+{
+	GtkApplication *application = user_data;
+	GList *windows;
+
+	/* nautilus_window_close() doesn't do anything for desktop windows */
+	windows = gtk_application_get_windows (application);
+	g_list_foreach (windows, (GFunc) nautilus_window_close, NULL);
+}
+
+static GActionEntry app_entries[] = {
+	{ "new-window", action_new_window, NULL, NULL, NULL },
+	{ "connect-to-server", action_connect_to_server, NULL, NULL, NULL },
+	{ "preferences", action_preferences, NULL, NULL, NULL },
+	{ "about", action_about, NULL, NULL, NULL },
+	{ "help", action_help, NULL, NULL, NULL },
+	{ "quit", action_quit, NULL, NULL, NULL },
+	{ "kill", action_kill, NULL, NULL, NULL },
+};
+
+static void
+nautilus_application_init_app_menu (NautilusApplication *self)
+{
+	GtkBuilder *builder;
+	GError *error = NULL;
+
+	g_action_map_add_action_entries (G_ACTION_MAP (self),
+					 app_entries, G_N_ELEMENTS (app_entries),
+					 self);
+
+	builder = gtk_builder_new ();
+	gtk_builder_add_from_resource (builder, "/org/gnome/nautilus/nautilus-app-menu.ui", &error);
+
+	if (error == NULL) {
+		gtk_application_set_app_menu (GTK_APPLICATION (self),
+					      G_MENU_MODEL (gtk_builder_get_object (builder, "app-menu")));
+	} else {
+		g_critical ("Unable to add the application menu: %s\n", error->message);
+		g_error_free (error);
+	}
+
+	g_object_unref (builder);
 }
 
 static void
 nautilus_application_init (NautilusApplication *application)
 {
-	GSimpleAction *action;
-
 	application->priv =
 		G_TYPE_INSTANCE_GET_PRIVATE (application, NAUTILUS_TYPE_APPLICATION,
 					     NautilusApplicationPriv);
-
-	action = g_simple_action_new ("quit", NULL);
-
-        g_action_map_add_action (G_ACTION_MAP (application), G_ACTION (action));
-
-	g_signal_connect_swapped (action, "activate",
-				  G_CALLBACK (nautilus_application_quit), application);
-
-	g_object_unref (action);
 }
 
 static void
@@ -815,9 +866,6 @@ nautilus_application_finalize (GObject *object)
 
 	application = NAUTILUS_APPLICATION (object);
 
-	nautilus_bookmarks_exiting ();
-
-	g_clear_object (&application->undo_manager);
 	g_clear_object (&application->priv->volume_monitor);
 	g_clear_object (&application->priv->progress_handler);
 
@@ -882,16 +930,6 @@ do_perform_self_checks (gint *exit_status)
 	*exit_status = EXIT_SUCCESS;
 }
 
-void
-nautilus_application_quit (NautilusApplication *self)
-{
-	GApplication *app = G_APPLICATION (self);
-	GList *windows;
-
-	windows = gtk_application_get_windows (GTK_APPLICATION (app));
-	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
-}
-
 static gboolean
 nautilus_application_local_command_line (GApplication *application,
 					 gchar ***arguments,
@@ -982,7 +1020,7 @@ nautilus_application_local_command_line (GApplication *application,
 	if (kill_shell) {
 		DEBUG ("Killing application, as requested");
 		g_action_group_activate_action (G_ACTION_GROUP (application),
-						"quit", NULL);
+						"kill", NULL);
 		goto out;
 	}
 
@@ -1065,50 +1103,6 @@ init_desktop (NautilusApplication *self)
 				  self);
 }
 
-static gboolean 
-nautilus_application_save_accel_map (gpointer data)
-{
-	if (save_of_accel_map_requested) {
-		char *accel_map_filename;
-	 	accel_map_filename = nautilus_get_accel_map_file ();
-	 	if (accel_map_filename) {
-	 		gtk_accel_map_save (accel_map_filename);
-	 		g_free (accel_map_filename);
-	 	}
-		save_of_accel_map_requested = FALSE;
-	}
-
-	return FALSE;
-}
-
-static void 
-queue_accel_map_save_callback (GtkAccelMap *object, gchar *accel_path,
-		guint accel_key, GdkModifierType accel_mods,
-		gpointer user_data)
-{
-	if (!save_of_accel_map_requested) {
-		save_of_accel_map_requested = TRUE;
-		g_timeout_add_seconds (NAUTILUS_ACCEL_MAP_SAVE_DELAY, 
-				nautilus_application_save_accel_map, NULL);
-	}
-}
-
-static void
-init_gtk_accels (void)
-{
-	char *accel_map_filename;
-
-	/* load accelerator map, and register save callback */
-	accel_map_filename = nautilus_get_accel_map_file ();
-	if (accel_map_filename) {
-		gtk_accel_map_load (accel_map_filename);
-		g_free (accel_map_filename);
-	}
-
-	g_signal_connect (gtk_accel_map_get (), "changed",
-			  G_CALLBACK (queue_accel_map_save_callback), NULL);
-}
-
 static void
 nautilus_application_startup (GApplication *app)
 {
@@ -1122,9 +1116,6 @@ nautilus_application_startup (GApplication *app)
 	/* initialize the previewer singleton */
 	nautilus_previewer_get_singleton ();
 
-	/* create an undo manager */
-	self->undo_manager = nautilus_undo_manager_new ();
-
 	/* create DBus manager */
 	nautilus_dbus_manager_start (app);
 	nautilus_freedesktop_dbus_start (self);
@@ -1146,7 +1137,6 @@ nautilus_application_startup (GApplication *app)
 
 	/* initialize theming */
 	init_icons_and_styles ();
-	init_gtk_accels ();
 	
 	/* initialize nautilus modules */
 	nautilus_module_setup ();
@@ -1173,6 +1163,8 @@ nautilus_application_startup (GApplication *app)
 	init_desktop (self);
 
 	do_upgrades_once (self);
+
+	nautilus_application_init_app_menu (self);
 }
 
 static void
@@ -1181,7 +1173,6 @@ nautilus_application_quit_mainloop (GApplication *app)
 	DEBUG ("Quitting mainloop");
 
 	nautilus_icon_info_clear_caches ();
- 	nautilus_application_save_accel_map (NULL);
 
 	G_APPLICATION_CLASS (nautilus_application_parent_class)->quit_mainloop (app);
 }
@@ -1210,7 +1201,6 @@ nautilus_application_class_init (NautilusApplicationClass *class)
 	GtkApplicationClass *gtkapp_class;
 
         object_class = G_OBJECT_CLASS (class);
-	object_class->constructor = nautilus_application_constructor;
         object_class->finalize = nautilus_application_finalize;
 
 	application_class = G_APPLICATION_CLASS (class);
@@ -1224,12 +1214,3 @@ nautilus_application_class_init (NautilusApplicationClass *class)
 
 	g_type_class_add_private (class, sizeof (NautilusApplicationPriv));
 }
-
-NautilusApplication *
-nautilus_application_get_singleton (void)
-{
-	return g_object_new (NAUTILUS_TYPE_APPLICATION,
-			     "application-id", "org.gnome.NautilusApplication",
-			     "flags", G_APPLICATION_HANDLES_OPEN,
-			     NULL);
-}
