@@ -93,13 +93,6 @@ static time_t desktop_dir_modify_time;
 
 #define get_icon_container(w) nautilus_icon_view_get_icon_container(NAUTILUS_ICON_VIEW (w))
 
-static void
-desktop_directory_changed_callback (gpointer callback_data)
-{
-	g_free (desktop_directory);
-	desktop_directory = nautilus_get_desktop_directory ();
-}
-
 static void
 icon_container_set_workarea (NautilusIconContainer *icon_container,
 			     GdkScreen             *screen,
@@ -288,11 +281,6 @@ nautilus_desktop_icon_view_dispose (GObject *object)
 	g_signal_handlers_disconnect_by_func (nautilus_preferences,
 					      font_changed_callback,
 					      icon_view);
-
-	g_signal_handlers_disconnect_by_func (nautilus_preferences,
-					      desktop_directory_changed_callback,
-					      NULL);
-
 	g_signal_handlers_disconnect_by_func (gnome_lockdown_preferences,
 					      nautilus_view_update_menus,
 					      icon_view);
@@ -566,10 +554,7 @@ nautilus_desktop_icon_view_init (NautilusDesktopIconView *desktop_icon_view)
 								  NautilusDesktopIconViewDetails);
 
 	if (desktop_directory == NULL) {
-		g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
-					  G_CALLBACK(desktop_directory_changed_callback),
-					  NULL);
-		desktop_directory_changed_callback (NULL);
+		desktop_directory = nautilus_get_desktop_directory ();
 	}
 
 	nautilus_icon_view_filter_by_screen (NAUTILUS_ICON_VIEW (desktop_icon_view), TRUE);
@@ -645,23 +630,6 @@ nautilus_desktop_icon_view_init (NautilusDesktopIconView *desktop_icon_view)
 				  desktop_icon_view);
 }
 
-static void
-action_new_launcher_callback (GtkAction *action, gpointer data)
-{
-	char *desktop_directory;
-
-        g_assert (NAUTILUS_VIEW (data));
-
-	desktop_directory = nautilus_get_desktop_directory ();
-
-	nautilus_launch_application_from_command (gtk_widget_get_screen (GTK_WIDGET (data)),
-						  "gnome-desktop-item-edit",
-						  FALSE,
-						  "--create-new", desktop_directory, NULL);
-	g_free (desktop_directory);
-
-}
-
 static void
 action_change_background_callback (GtkAction *action, 
 				   gpointer data)
@@ -694,7 +662,7 @@ trash_link_is_selection (NautilusView *view)
 	
 	selection = nautilus_view_get_selection (view);
 
-	if (eel_g_list_exactly_one_item (selection) &&
+	if ((g_list_length (selection) == 1) &&
 	    NAUTILUS_IS_DESKTOP_ICON_FILE (selection->data)) {
 		link = nautilus_desktop_icon_file_get_link (NAUTILUS_DESKTOP_ICON_FILE (selection->data));
 		/* link may be NULL if the link was recently removed (unmounted) */
@@ -717,7 +685,6 @@ real_update_menus (NautilusView *view)
 {
 	NautilusDesktopIconView *desktop_view;
 	char *label;
-	gboolean disable_command_line;
 	gboolean include_empty_trash;
 	GtkAction *action;
 
@@ -727,13 +694,6 @@ real_update_menus (NautilusView *view)
 
 	desktop_view = NAUTILUS_DESKTOP_ICON_VIEW (view);
 
-	/* New Launcher */
-	disable_command_line = g_settings_get_boolean (gnome_lockdown_preferences, NAUTILUS_PREFERENCES_LOCKDOWN_COMMAND_LINE);
-	action = gtk_action_group_get_action (desktop_view->details->desktop_action_group,
-					      NAUTILUS_ACTION_NEW_LAUNCHER_DESKTOP);
-	gtk_action_set_visible (action,
-				!disable_command_line);
-
 	/* Empty Trash */
 	include_empty_trash = trash_link_is_selection (view);
 	action = gtk_action_group_get_action (desktop_view->details->desktop_action_group,
@@ -751,13 +711,6 @@ real_update_menus (NautilusView *view)
 
 static const GtkActionEntry desktop_view_entries[] = {
 	/* name, stock id */
-	{ "New Launcher Desktop", NULL,
-	  /* label, accelerator */
-	  N_("Create L_auncher..."), NULL,
-	  /* tooltip */
-	  N_("Create a new launcher"),
-	  G_CALLBACK (action_new_launcher_callback) },
-	/* name, stock id */
 	{ "Change Background", NULL,
 	  /* label, accelerator */
 	  N_("Change Desktop _Background"), NULL,
@@ -779,7 +732,6 @@ real_merge_menus (NautilusView *view)
 	NautilusDesktopIconView *desktop_view;
 	GtkUIManager *ui_manager;
 	GtkActionGroup *action_group;
-	const char *ui;
 
 	NAUTILUS_VIEW_CLASS (nautilus_desktop_icon_view_parent_class)->merge_menus (view);
 
@@ -797,9 +749,8 @@ real_merge_menus (NautilusView *view)
 	gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
 	g_object_unref (action_group); /* owned by ui manager */
 
-	ui = nautilus_ui_string_get ("nautilus-desktop-icon-view-ui.xml");
 	desktop_view->details->desktop_merge_id =
-		gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, NULL);
+		gtk_ui_manager_add_ui_from_resource (ui_manager, "/org/gnome/nautilus/nautilus-desktop-icon-view-ui.xml", NULL);
 }
 
 static NautilusView *
