@@ -48,15 +48,18 @@ G_DEFINE_TYPE (NautilusDesktopWindow, nautilus_desktop_window,
 	       NAUTILUS_TYPE_WINDOW);
 
 static void
-nautilus_desktop_window_dispose (GObject *obj)
+nautilus_desktop_window_update_directory (NautilusDesktopWindow *window)
 {
-	NautilusDesktopWindow *window = NAUTILUS_DESKTOP_WINDOW (obj);
+	GFile *location;
 
-	g_signal_handlers_disconnect_by_func (nautilus_preferences,
-					      nautilus_desktop_window_update_directory,
-					      window);
+	g_assert (NAUTILUS_IS_DESKTOP_WINDOW (window));
 
-	G_OBJECT_CLASS (nautilus_desktop_window_parent_class)->dispose (obj);
+	window->details->loaded = FALSE;
+	location = g_file_new_for_uri (EEL_DESKTOP_URI);
+	nautilus_window_go_to (NAUTILUS_WINDOW (window), location);
+	window->details->loaded = TRUE;
+
+	g_object_unref (location);
 }
 
 static void
@@ -91,12 +94,6 @@ nautilus_desktop_window_constructed (GObject *obj)
 	if (accessible) {
 		atk_object_set_name (accessible, _("Desktop"));
 	}
-
-	/* Monitor the preference to have the desktop */
-	/* point to the Unix home folder */
-	g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
-				  G_CALLBACK (nautilus_desktop_window_update_directory),
-				  window);
 }
 
 static void
@@ -117,28 +114,6 @@ nautilus_desktop_window_init (NautilusDesktopWindow *window)
 			   GINT_TO_POINTER (1));
 }
 
-static gint
-nautilus_desktop_window_delete_event (NautilusDesktopWindow *window)
-{
-	/* Returning true tells GTK+ not to delete the window. */
-	return TRUE;
-}
-
-void
-nautilus_desktop_window_update_directory (NautilusDesktopWindow *window)
-{
-	GFile *location;
-
-	g_assert (NAUTILUS_IS_DESKTOP_WINDOW (window));
-
-	window->details->loaded = FALSE;
-	location = g_file_new_for_uri (EEL_DESKTOP_URI);
-	nautilus_window_go_to (NAUTILUS_WINDOW (window), location);
-	window->details->loaded = TRUE;
-
-	g_object_unref (location);
-}
-
 static void
 nautilus_desktop_window_screen_size_changed (GdkScreen             *screen,
 					     NautilusDesktopWindow *window)
@@ -155,7 +130,8 @@ nautilus_desktop_window_screen_size_changed (GdkScreen             *screen,
 }
 
 NautilusDesktopWindow *
-nautilus_desktop_window_new (GdkScreen *screen)
+nautilus_desktop_window_new (GtkApplication *application,
+			     GdkScreen      *screen)
 {
 	NautilusDesktopWindow *window;
 	int width_request, height_request;
@@ -164,6 +140,7 @@ nautilus_desktop_window_new (GdkScreen *screen)
 	height_request = gdk_screen_get_height (screen);
 
 	window = g_object_new (NAUTILUS_TYPE_DESKTOP_WINDOW,
+			       "application", application,
 			       "disable-chrome", TRUE,
 			       "width_request", width_request,
 			       "height_request", height_request,
@@ -173,8 +150,6 @@ nautilus_desktop_window_new (GdkScreen *screen)
 	/* Special sawmill setting*/
 	gtk_window_set_wmclass (GTK_WINDOW (window), "desktop_window", "Nautilus");
 
-	g_signal_connect (window, "delete_event", G_CALLBACK (nautilus_desktop_window_delete_event), NULL);
-
 	/* Point window at the desktop folder.
 	 * Note that nautilus_desktop_window_init is too early to do this.
 	 */
@@ -183,6 +158,14 @@ nautilus_desktop_window_new (GdkScreen *screen)
 	return window;
 }
 
+static gboolean
+nautilus_desktop_window_delete_event (GtkWidget *widget,
+				      GdkEventAny *event)
+{
+	/* Returning true tells GTK+ not to delete the window. */
+	return TRUE;
+}
+
 static void
 map (GtkWidget *widget)
 {
@@ -305,11 +288,11 @@ nautilus_desktop_window_class_init (NautilusDesktopWindowClass *klass)
 	GObjectClass *oclass = G_OBJECT_CLASS (klass);
 
 	oclass->constructed = nautilus_desktop_window_constructed;
-	oclass->dispose = nautilus_desktop_window_dispose;
 
 	wclass->realize = realize;
 	wclass->unrealize = unrealize;
 	wclass->map = map;
+	wclass->delete_event = nautilus_desktop_window_delete_event;
 
 	nclass->sync_title = real_sync_title;
 	nclass->get_icon = real_get_icon;
