@@ -436,16 +436,8 @@ nautilus_notebook_add_tab (NautilusNotebook *notebook,
 	nautilus_notebook_sync_tab_label (notebook, slot);
 	nautilus_notebook_sync_loading (notebook, slot);
 
-
-	/* FIXME gtk bug! */
-	/* FIXME: this should be fixed in gtk 2.12; check & remove this! */
-	/* The signal handler may have reordered the tabs */
-	position = gtk_notebook_page_num (gnotebook, GTK_WIDGET (slot));
-
-	if (jump_to)
-	{
+	if (jump_to) {
 		gtk_notebook_set_current_page (gnotebook, position);
-
 	}
 
 	return position;
