@@ -258,13 +258,6 @@ get_eject_icon (NautilusPlacesSidebar *sidebar,
 	return eject;
 }
 
-static gboolean
-should_show_desktop (void)
-{
-	return g_settings_get_boolean (gnome_background_preferences, NAUTILUS_PREFERENCES_SHOW_DESKTOP) &&
-	       !g_settings_get_boolean (nautilus_preferences, NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR);
-}
-
 static gboolean
 is_built_in_bookmark (NautilusFile *file)
 {
@@ -275,7 +268,8 @@ is_built_in_bookmark (NautilusFile *file)
 		return TRUE;
 	}
 
-	if (nautilus_file_is_desktop_directory (file) && !should_show_desktop ()) {
+	if (nautilus_file_is_desktop_directory (file) &&
+	    !g_settings_get_boolean (gnome_background_preferences, NAUTILUS_PREFERENCES_SHOW_DESKTOP)) {
 		return FALSE;
 	}
 
@@ -479,7 +473,7 @@ update_places (NautilusPlacesSidebar *sidebar)
 	GList *volumes;
 	GVolume *volume;
 	int bookmark_count, index;
-	char *location, *mount_uri, *name, *desktop_path, *last_uri, *identifier;
+	char *location, *mount_uri, *name, *last_uri, *identifier;
 	const gchar *path, *bookmark_name;
 	GIcon *icon;
 	GFile *root;
@@ -703,10 +697,9 @@ update_places (NautilusPlacesSidebar *sidebar)
 	g_object_unref (icon);
 	g_free (mount_uri);
 
-	if (should_show_desktop ()) {
+	if (g_settings_get_boolean (gnome_background_preferences, NAUTILUS_PREFERENCES_SHOW_DESKTOP)) {
 		/* desktop */
-		desktop_path = nautilus_get_desktop_directory ();
-		mount_uri = g_filename_to_uri (desktop_path, NULL, NULL);
+		mount_uri = nautilus_get_desktop_directory_uri ();
 		icon = g_themed_icon_new (NAUTILUS_ICON_DESKTOP);
 		add_place (sidebar, PLACES_BUILT_IN,
 			   SECTION_COMPUTER,
@@ -715,7 +708,6 @@ update_places (NautilusPlacesSidebar *sidebar)
 			   _("Open the contents of your desktop in a folder"));
 		g_object_unref (icon);
 		g_free (mount_uri);
-		g_free (desktop_path);
 	}
 
 	
@@ -774,7 +766,7 @@ update_places (NautilusPlacesSidebar *sidebar)
 		root = g_mount_get_default_location (mount);
 
 		if (!g_file_is_native (root)) {
-			network_mounts = g_list_prepend (network_mounts, mount);
+			network_mounts = g_list_prepend (network_mounts, g_object_ref (mount));
 			continue;
 		}
 
@@ -856,6 +848,7 @@ update_places (NautilusPlacesSidebar *sidebar)
 			   name, icon, mount_uri,
 			   NULL, NULL, mount, 0, tooltip);
 		g_object_unref (root);
+		g_object_unref (mount);
 		g_object_unref (icon);
 		g_free (name);
 		g_free (mount_uri);
@@ -1796,12 +1789,12 @@ volume_mounted_cb (GVolume *volume,
 		if (sidebar->go_to_after_mount_slot != NULL) {
 			if ((sidebar->go_to_after_mount_flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW) == 0) {
 				nautilus_window_slot_open_location (sidebar->go_to_after_mount_slot, location,
-								    sidebar->go_to_after_mount_flags, NULL);
+								    sidebar->go_to_after_mount_flags);
 			} else {
 				NautilusWindow *new, *cur;
 
 				cur = NAUTILUS_WINDOW (sidebar->window);
-				new = nautilus_application_create_window (nautilus_application_get_singleton (),
+				new = nautilus_application_create_window (NAUTILUS_APPLICATION (g_application_get_default ()),
 									  gtk_window_get_screen (GTK_WINDOW (cur)));
 				nautilus_window_go_to (new, location);
 			}
@@ -1811,8 +1804,10 @@ volume_mounted_cb (GVolume *volume,
 		g_object_unref (G_OBJECT (mount));
 	}
 
-	
-	eel_remove_weak_pointer (&(sidebar->go_to_after_mount_slot));
+	if (sidebar->go_to_after_mount_slot) {
+		g_object_remove_weak_pointer (G_OBJECT (sidebar->go_to_after_mount_slot),
+					      (gpointer *) &sidebar->go_to_after_mount_slot);
+	}
 }
 
 static void
@@ -1862,13 +1857,12 @@ open_selected_bookmark (NautilusPlacesSidebar *sidebar,
 		/* Navigate to the clicked location */
 		if ((flags & NAUTILUS_WINDOW_OPEN_FLAG_NEW_WINDOW) == 0) {
 			slot = nautilus_window_get_active_slot (sidebar->window);
-			nautilus_window_slot_open_location (slot, location,
-							    flags, NULL);
+			nautilus_window_slot_open_location (slot, location, flags);
 		} else {
 			NautilusWindow *cur, *new;
 			
 			cur = NAUTILUS_WINDOW (sidebar->window);
-			new = nautilus_application_create_window (nautilus_application_get_singleton (),
+			new = nautilus_application_create_window (NAUTILUS_APPLICATION (g_application_get_default ()),
 								  gtk_window_get_screen (GTK_WINDOW (cur)));
 			nautilus_window_go_to (new, location);
 		}
@@ -1892,7 +1886,8 @@ open_selected_bookmark (NautilusPlacesSidebar *sidebar,
 
 			slot = nautilus_window_get_active_slot (sidebar->window);
 			sidebar->go_to_after_mount_slot = slot;
-			eel_add_weak_pointer (&(sidebar->go_to_after_mount_slot));
+			g_object_add_weak_pointer (G_OBJECT (sidebar->go_to_after_mount_slot),
+						   (gpointer *) &sidebar->go_to_after_mount_slot);
 
 			sidebar->go_to_after_mount_flags = flags;
 
@@ -2989,7 +2984,6 @@ bookmarks_button_press_event_cb (GtkWidget             *widget,
 	GtkTreeIter iter;
 	GtkTreePath *path = NULL;
 	gboolean retval = FALSE;
-	PlaceType row_type;
 
 	if (event->type != GDK_BUTTON_PRESS) {
 		/* ignore multiple clicks */
@@ -3006,13 +3000,7 @@ bookmarks_button_press_event_cb (GtkWidget             *widget,
 	}
 
 	if (event->button == 3) {
-		gtk_tree_model_get (model, &iter,
-				    PLACES_SIDEBAR_COLUMN_ROW_TYPE, &row_type,
-				    -1);
-
-		if (row_type != PLACES_HEADING) {
-			bookmarks_popup_menu (sidebar, event);
-		}
+		bookmarks_popup_menu (sidebar, event);
 	} else if (event->button == 2) {
 		NautilusWindowOpenFlags flags = 0;
 
@@ -3405,10 +3393,6 @@ nautilus_places_sidebar_init (NautilusPlacesSidebar *sidebar)
 	eel_gtk_tree_view_set_activate_on_single_click (sidebar->tree_view,
 							TRUE);
 
-	g_signal_connect_swapped (nautilus_preferences, "changed::" NAUTILUS_PREFERENCES_DESKTOP_IS_HOME_DIR,
-				  G_CALLBACK(desktop_setting_changed_callback),
-				  sidebar);
-
 	g_signal_connect_swapped (gnome_background_preferences, "changed::" NAUTILUS_PREFERENCES_SHOW_DESKTOP,
 				  G_CALLBACK(desktop_setting_changed_callback),
 				  sidebar);
@@ -3448,11 +3432,11 @@ nautilus_places_sidebar_dispose (GObject *object)
 	g_clear_object (&sidebar->store);
 	g_clear_object (&sidebar->bookmarks);
 
-	eel_remove_weak_pointer (&(sidebar->go_to_after_mount_slot));
-
-	g_signal_handlers_disconnect_by_func (nautilus_preferences,
-					      desktop_setting_changed_callback,
-					      sidebar);
+	if (sidebar->go_to_after_mount_slot) {
+		g_object_remove_weak_pointer (G_OBJECT (sidebar->go_to_after_mount_slot),
+					      (gpointer *) &sidebar->go_to_after_mount_slot);
+		sidebar->go_to_after_mount_slot = NULL;
+	}
 
 	g_signal_handlers_disconnect_by_func (nautilus_preferences,
 					      bookmarks_popup_menu_detach_cb,
