@@ -33,7 +33,6 @@
 #include "nautilus-bookmarks-window.h"
 #include "nautilus-window-bookmarks.h"
 #include "nautilus-window-private.h"
-#include <libnautilus-private/nautilus-undo-manager.h>
 #include <libnautilus-private/nautilus-ui-utilities.h>
 #include <eel/eel-debug.h>
 #include <eel/eel-stock-dialogs.h>
@@ -100,38 +99,6 @@ show_bogus_bookmark_window (NautilusWindow *window,
 	g_free (detail);
 }
 
-static GtkWindow *
-get_or_create_bookmarks_window (NautilusWindow *window)
-{
-	GObject *undo_manager_source;
-
-	undo_manager_source = G_OBJECT (window);
-
-	if (bookmarks_window == NULL) {
-		bookmarks_window = create_bookmarks_window (window->details->bookmark_list,
-		                                            undo_manager_source);
-	} else {
-		edit_bookmarks_dialog_set_signals (undo_manager_source);
-	}
-
-	return bookmarks_window;
-}
-
-/**
- * nautilus_bookmarks_exiting:
- * 
- * Last chance to save state before app exits.
- * Called when application exits; don't call from anywhere else.
- **/
-void
-nautilus_bookmarks_exiting (void)
-{
-	if (bookmarks_window != NULL) {
-		nautilus_bookmarks_window_save_geometry (bookmarks_window);
-		gtk_widget_destroy (GTK_WIDGET (bookmarks_window));
-	}
-}
-
 /**
  * add_bookmark_for_current_location
  * 
@@ -157,13 +124,14 @@ nautilus_window_add_bookmark_for_current_location (NautilusWindow *window)
 void
 nautilus_window_edit_bookmarks (NautilusWindow *window)
 {
-	GtkWindow *dialog;
+	if (bookmarks_window == NULL) {
+		bookmarks_window = nautilus_bookmarks_window_new (window, window->details->bookmark_list);
+		g_object_add_weak_pointer (G_OBJECT (bookmarks_window), (gpointer *) &bookmarks_window);
+	}
 
-	dialog = get_or_create_bookmarks_window (window);
-
-	gtk_window_set_screen (
-		dialog, gtk_window_get_screen (GTK_WINDOW (window)));
-        gtk_window_present (dialog);
+	gtk_window_set_transient_for (bookmarks_window, GTK_WINDOW (window));
+	gtk_window_set_screen (GTK_WINDOW (bookmarks_window), gtk_window_get_screen (GTK_WINDOW (window)));
+        gtk_window_present (bookmarks_window);
 }
 
 static void
@@ -274,9 +242,8 @@ activate_bookmark_in_menu_item (GtkAction *action, gpointer user_data)
 	} else {
 	        location = nautilus_bookmark_get_location (holder->bookmark);
 		slot = nautilus_window_get_active_slot (holder->window);
-	        nautilus_window_slot_go_to (slot, 
-					    location, 
-					    nautilus_event_should_open_in_new_tab ());
+	        nautilus_window_slot_open_location (slot, location, 
+						    nautilus_event_get_window_open_flags ());
 	        g_object_unref (location);
         }
 }
