@@ -320,7 +320,7 @@ viewed_file_changed_callback (NautilusFile *file,
 					nautilus_path_bar_clear_buttons (NAUTILUS_PATH_BAR (slot->pane->path_bar));
 				}
 				
-				nautilus_window_slot_go_to (slot, go_to_file, FALSE);
+				nautilus_window_slot_open_location (slot, go_to_file, 0);
 				g_object_unref (go_to_file);
 			} else {
 				nautilus_window_slot_go_home (slot, FALSE);
@@ -417,7 +417,6 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 	GList *l;
 	gboolean use_same;
 	gboolean is_desktop;
-	NautilusApplication *app;
 
 	window = nautilus_window_slot_get_window (slot);
 
@@ -468,9 +467,8 @@ nautilus_window_slot_open_location_full (NautilusWindowSlot *slot,
 	if (use_same) {
 		target_window = window;
 	} else {
-		app = nautilus_application_get_singleton ();
 		target_window = nautilus_application_create_window
-			(app,
+			(NAUTILUS_APPLICATION (g_application_get_default ()),
 			 gtk_window_get_screen (GTK_WINDOW (window)));
 	}
 
@@ -768,11 +766,11 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 	char *mimetype;
 	NautilusWindow *window;
 	NautilusWindowSlot *slot;
-	NautilusFile *viewed_file, *parent_file;
+	NautilusFile *viewed_file;
 	GFile *location;
 	GMountOperation *mount_op;
 	MountNotMountedData *data;
-	NautilusApplication *app;
+	GtkApplication *app;
 
 	slot = callback_data;
 	window = nautilus_window_slot_get_window (slot);
@@ -807,9 +805,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 		return;
 	}
 
-	parent_file = nautilus_file_get_parent (file);
-	if ((parent_file != NULL) &&
-	    nautilus_file_get_file_type (file) == G_FILE_TYPE_REGULAR) {
+	if (nautilus_file_get_file_type (file) == G_FILE_TYPE_REGULAR) {
 		if (slot->pending_selection != NULL) {
 			g_list_free_full (slot->pending_selection, (GDestroyNotify) nautilus_file_unref);
 		}
@@ -819,7 +815,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 	
 		slot->pending_location = nautilus_file_get_parent_location (file);
 		slot->pending_selection = g_list_prepend (NULL, nautilus_file_ref (file));
-		slot->determine_view_file = parent_file;
+		slot->determine_view_file = nautilus_file_get_parent (file);
 		slot->pending_scroll_to = nautilus_file_get_uri (file);
 
 		nautilus_file_invalidate_all_attributes (slot->determine_view_file);
@@ -833,7 +829,6 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 		return;
 	}
 
-	nautilus_file_unref (parent_file);
 	location = slot->pending_location;
 	
 	view_id = NULL;
@@ -890,9 +885,9 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 			 */
 			/* if this is the only window, we don't want to quit, so we redirect it to home */
 
-			app = nautilus_application_get_singleton ();
-			
-			if (g_list_length (gtk_application_get_windows (GTK_APPLICATION (app))) == 1) {
+			app = GTK_APPLICATION (g_application_get_default ());
+
+			if (g_list_length (gtk_application_get_windows (app)) == 1) {
 				/* the user could have typed in a home directory that doesn't exist,
 				   in which case going home would cause an infinite loop, so we
 				   better test for that */
@@ -905,7 +900,7 @@ got_file_info_for_view_selection_callback (NautilusFile *file,
 
 						root = g_file_new_for_path ("/");
 						/* the last fallback is to go to a known place that can't be deleted! */
-						nautilus_window_slot_go_to (slot, location, FALSE);
+						nautilus_window_slot_open_location (slot, location, 0);
 						g_object_unref (root);
 					}
 				} else {
@@ -1754,7 +1749,7 @@ void
 nautilus_window_back_or_forward (NautilusWindow *window, 
 				 gboolean back,
 				 guint distance,
-				 gboolean new_tab)
+				 NautilusWindowOpenFlags flags)
 {
 	NautilusWindowSlot *slot;
 	GList *list;
@@ -1780,10 +1775,8 @@ nautilus_window_back_or_forward (NautilusWindow *window,
         bookmark = g_list_nth_data (list, distance);
 	location = nautilus_bookmark_get_location (bookmark);
 
-	if (new_tab) {
-		nautilus_window_slot_open_location_full (slot, location,
-							 NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB,
-							 NULL, NULL, NULL);
+	if (flags != 0) {
+		nautilus_window_slot_open_location (slot, location, flags);
 	} else {
 		char *scroll_pos;
 
