@@ -53,7 +53,6 @@
 #include <libnautilus-private/nautilus-icon-names.h>
 #include <libnautilus-private/nautilus-ui-utilities.h>
 #include <libnautilus-private/nautilus-module.h>
-#include <libnautilus-private/nautilus-undo-manager.h>
 #include <libnautilus-private/nautilus-program-choosing.h>
 #include <libnautilus-private/nautilus-search-directory.h>
 #include <libnautilus-private/nautilus-search-engine.h>
@@ -66,7 +65,6 @@
 
 #define NETWORK_URI          "network:"
 #define COMPUTER_URI         "computer:"
-#define BURN_CD_URI          "burn:"
 
 static void
 action_close_window_slot_callback (GtkAction *action,
@@ -85,12 +83,8 @@ static void
 action_connect_to_server_callback (GtkAction *action, 
 				   gpointer user_data)
 {
-	NautilusWindow *window = NAUTILUS_WINDOW (user_data);
-	GtkWidget *dialog;
-
-	dialog = nautilus_connect_server_dialog_new (window);
-
-	gtk_widget_show (dialog);
+	g_action_group_activate_action (G_ACTION_GROUP (g_application_get_default ()),
+					"connect-to-server", NULL);
 }
 
 static void
@@ -106,18 +100,6 @@ action_stop_callback (GtkAction *action,
 	nautilus_window_slot_stop_loading (slot);
 }
 
-#ifdef TEXT_CHANGE_UNDO
-static void
-action_undo_callback (GtkAction *action, 
-		      gpointer user_data) 
-{
-	NautilusApplication *app;
-
-	app = nautilus_application_get_singleton ();
-	nautilus_undo_manager_undo (app->undo_manager);
-}
-#endif
-
 static void
 action_home_callback (GtkAction *action, 
 		      gpointer user_data) 
@@ -128,8 +110,8 @@ action_home_callback (GtkAction *action,
 	window = NAUTILUS_WINDOW (user_data);
 	slot = nautilus_window_get_active_slot (window);
 
-	nautilus_window_slot_go_home (slot, 
-				      nautilus_event_should_open_in_new_tab ());
+	nautilus_window_slot_go_home (slot,
+				      nautilus_event_get_window_open_flags ());
 }
 
 static void
@@ -144,9 +126,8 @@ action_go_to_computer_callback (GtkAction *action,
 	slot = nautilus_window_get_active_slot (window);
 
 	computer = g_file_new_for_uri (COMPUTER_URI);
-	nautilus_window_slot_go_to (slot,
-				    computer,
-				    nautilus_event_should_open_in_new_tab ());
+	nautilus_window_slot_open_location (slot, computer,
+					    nautilus_event_get_window_open_flags ());
 	g_object_unref (computer);
 }
 
@@ -162,9 +143,8 @@ action_go_to_network_callback (GtkAction *action,
 	slot = nautilus_window_get_active_slot (window);
 
 	network = g_file_new_for_uri (NETWORK_URI);
-	nautilus_window_slot_go_to (slot,
-				    network,
-				    nautilus_event_should_open_in_new_tab ());
+	nautilus_window_slot_open_location (slot, network,
+					    nautilus_event_get_window_open_flags ());
 	g_object_unref (network);
 }
 
@@ -183,9 +163,8 @@ action_go_to_templates_callback (GtkAction *action,
 	path = nautilus_get_templates_directory ();
 	location = g_file_new_for_path (path);
 	g_free (path);
-	nautilus_window_slot_go_to (slot,
-				    location,
-				    nautilus_event_should_open_in_new_tab ());
+	nautilus_window_slot_open_location (slot, location,
+					    nautilus_event_get_window_open_flags ());
 	g_object_unref (location);
 }
 
@@ -201,9 +180,8 @@ action_go_to_trash_callback (GtkAction *action,
 	slot = nautilus_window_get_active_slot (window);
 
 	trash = g_file_new_for_uri ("trash:///");
-	nautilus_window_slot_go_to (slot,
-				    trash,
-				    nautilus_event_should_open_in_new_tab ());
+	nautilus_window_slot_open_location (slot, trash,
+					    nautilus_event_get_window_open_flags ());
 	g_object_unref (trash);
 }
 
@@ -297,113 +275,16 @@ static void
 action_preferences_callback (GtkAction *action, 
 			     gpointer user_data)
 {
-	GtkWindow *window;
-
-	window = GTK_WINDOW (user_data);
-
-	nautilus_file_management_properties_dialog_show (window);
+	g_action_group_activate_action (G_ACTION_GROUP (g_application_get_default ()),
+					"preferences", NULL);
 }
 
 static void
 action_about_nautilus_callback (GtkAction *action,
 				gpointer user_data)
 {
-	const gchar *authors[] = {
-		"Alexander Larsson",
-		"Ali Abdin",
-		"Anders Carlsson",
-		"Andrew Walton",
-		"Andy Hertzfeld",
-		"Arlo Rose",
-		"Christian Neumair",
-		"Cosimo Cecchi",
-		"Darin Adler",
-		"David Camp",
-		"Eli Goldberg",
-		"Elliot Lee",
-		"Eskil Heyn Olsen",
-		"Ettore Perazzoli",
-		"Gene Z. Ragan",
-		"George Lebl",
-		"Ian McKellar",
-		"J Shane Culpepper",
-		"James Willcox",
-		"Jan Arne Petersen",
-		"John Harper",
-		"John Sullivan",
-		"Josh Barrow",
-		"Maciej Stachowiak",
-		"Mark McLoughlin",
-		"Mathieu Lacage",
-		"Mike Engber",
-		"Mike Fleming",
-		"Pavel Cisler",
-		"Ramiro Estrugo",
-		"Raph Levien",
-		"Rebecca Schulman",
-		"Robey Pointer",
-		"Robin * Slomkowski",
-		"Seth Nickell",
-		"Susan Kare",
-		"Tomas Bzatek",
-		NULL
-	};
-	const gchar *documenters[] = {
-		"GNOME Documentation Team",
-		"Sun Microsystems",
-		NULL
-	};
-	const gchar *license[] = {
-		N_("Nautilus is free software; you can redistribute it and/or modify "
-		   "it under the terms of the GNU General Public License as published by "
-		   "the Free Software Foundation; either version 2 of the License, or "
-		   "(at your option) any later version."),
-		N_("Nautilus is distributed in the hope that it will be useful, "
-		   "but WITHOUT ANY WARRANTY; without even the implied warranty of "
-		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
-		   "GNU General Public License for more details."),
-		N_("You should have received a copy of the GNU General Public License "
-		   "along with Nautilus; if not, write to the Free Software Foundation, Inc., "
-		   "51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA")
-	};
-	gchar *license_trans, *copyright_str;
-	GDateTime *date;
-
-	license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]),
-					     _(license[2]), NULL);
-
-	date = g_date_time_new_now_local ();
-
-	/* Translators: these two strings here indicate the copyright time span,
-	 * e.g. 1999-2011.
-	 */
-	copyright_str = g_strdup_printf (_("Copyright \xC2\xA9 %Id\xE2\x80\x93%Id "
-					   "The Nautilus authors"), 1999, g_date_time_get_year (date));
-
-	gtk_show_about_dialog (GTK_WINDOW (user_data),
-			       "program-name", _("Nautilus"),
-			       "version", VERSION,
-			       "comments", _("Nautilus lets you organize "
-					     "files and folders, both on "
-					     "your computer and online."),
-			       "copyright", copyright_str,
-			       "license", license_trans,
-			       "wrap-license", TRUE,
-			       "authors", authors,
-			       "documenters", documenters,
-				/* Translators should localize the following string
-				 * which will be displayed at the bottom of the about
-				 * box to give credit to the translator(s).
-				 */
-			      "translator-credits", _("translator-credits"),
-			      "logo-icon-name", "nautilus",
-			      "website", "http://live.gnome.org/Nautilus",
-			      "website-label", _("Nautilus Web Site"),
-			      NULL);
-
-	g_free (license_trans);
-	g_free (copyright_str);
-	g_date_time_unref (date);
+	g_action_group_activate_action (G_ACTION_GROUP (g_application_get_default ()),
+					"about", NULL);
 }
 
 static void
@@ -414,7 +295,7 @@ action_up_callback (GtkAction *action,
 	NautilusWindowSlot *slot;
 
 	slot = nautilus_window_get_active_slot (window);
-	nautilus_window_slot_go_up (slot, FALSE, nautilus_event_should_open_in_new_tab ());
+	nautilus_window_slot_go_up (slot, nautilus_event_get_window_open_flags ());
 }
 
 static void
@@ -551,7 +432,8 @@ static void
 action_close_all_windows_callback (GtkAction *action, 
 				   gpointer user_data)
 {
-	nautilus_application_close_all_windows (nautilus_application_get_singleton ());
+	g_action_group_activate_action (G_ACTION_GROUP (g_application_get_default ()),
+					"quit", NULL);
 }
 
 static void
@@ -559,7 +441,7 @@ action_back_callback (GtkAction *action,
 		      gpointer user_data) 
 {
 	nautilus_window_back_or_forward (NAUTILUS_WINDOW (user_data), 
-					 TRUE, 0, nautilus_event_should_open_in_new_tab ());
+					 TRUE, 0, nautilus_event_get_window_open_flags ());
 }
 
 static void
@@ -567,7 +449,7 @@ action_forward_callback (GtkAction *action,
 			 gpointer user_data) 
 {
 	nautilus_window_back_or_forward (NAUTILUS_WINDOW (user_data), 
-					 FALSE, 0, nautilus_event_should_open_in_new_tab ());
+					 FALSE, 0, nautilus_event_get_window_open_flags ());
 }
 
 static void
@@ -593,7 +475,8 @@ action_split_view_same_location_callback (GtkAction *action,
 	}
 	location = nautilus_window_slot_get_location (next_pane->active_slot);
 	if (location) {
-		nautilus_window_slot_go_to (nautilus_window_get_active_slot (window), location, FALSE);
+		nautilus_window_slot_open_location (nautilus_window_get_active_slot (window),
+						    location, 0);
 		g_object_unref (location);
 	}
 }
@@ -792,16 +675,8 @@ static void
 action_new_window_callback (GtkAction *action,
 			    gpointer user_data)
 {
-	NautilusApplication *application;
-	NautilusWindow *current_window, *new_window;
-
-	current_window = NAUTILUS_WINDOW (user_data);
-	application = nautilus_application_get_singleton ();
-
-	new_window = nautilus_application_create_window (
-				application,
-				gtk_window_get_screen (GTK_WINDOW (current_window)));
-	nautilus_window_slot_go_home (nautilus_window_get_active_slot (new_window), FALSE);
+	g_action_group_activate_action (G_ACTION_GROUP (g_application_get_default ()),
+					"new-window", NULL);
 }
 
 static void
@@ -916,15 +791,10 @@ static const GtkActionEntry main_entries[] = {
   /* label, accelerator */       N_("_Close"), "<control>W",
   /* tooltip */                  N_("Close this folder"),
                                  G_CALLBACK (action_close_window_slot_callback) },
-                               { "Preferences", GTK_STOCK_PREFERENCES,
+                               { NAUTILUS_ACTION_PREFERENCES, GTK_STOCK_PREFERENCES,
                                  N_("Prefere_nces"),               
                                  NULL, N_("Edit Nautilus preferences"),
                                  G_CALLBACK (action_preferences_callback) },
-#ifdef TEXT_CHANGE_UNDO
-  /* name, stock id, label */  { "Undo", NULL, N_("_Undo"),
-                                 "<control>Z", N_("Undo the last text change"),
-                                 G_CALLBACK (action_undo_callback) },
-#endif
   /* name, stock id, label */  { "Up", GTK_STOCK_GO_UP, N_("Open _Parent"),
                                  "<alt>Up", N_("Open the parent folder"),
                                  G_CALLBACK (action_up_callback) },
@@ -939,7 +809,7 @@ static const GtkActionEntry main_entries[] = {
   /* label, accelerator */       N_("_Reload"), "<control>R",
   /* tooltip */                  N_("Reload the current location"),
                                  G_CALLBACK (action_reload_callback) },
-  /* name, stock id */         { "NautilusHelp", GTK_STOCK_HELP,
+  /* name, stock id */         { NAUTILUS_ACTION_HELP, GTK_STOCK_HELP,
   /* label, accelerator */       N_("_All Topics"), "F1",
   /* tooltip */                  N_("Display Nautilus help"),
                                  G_CALLBACK (action_nautilus_manual_callback) },
@@ -959,7 +829,7 @@ static const GtkActionEntry main_entries[] = {
   /* label, accelerator */       N_("Share and transfer files"), NULL,
   /* tooltip */                  N_("Easily transfer files to your contacts and devices from the file manager."),
                                  G_CALLBACK (action_nautilus_manual_callback) },
-  /* name, stock id */         { "About Nautilus", GTK_STOCK_ABOUT,
+  /* name, stock id */         { NAUTILUS_ACTION_ABOUT, GTK_STOCK_ABOUT,
   /* label, accelerator */       N_("_About"), NULL,
   /* tooltip */                  N_("Display credits for the creators of Nautilus"),
                                  G_CALLBACK (action_about_nautilus_callback) },
@@ -987,7 +857,7 @@ static const GtkActionEntry main_entries[] = {
   /* label, accelerator */       N_("Normal Si_ze"), "<control>0",
   /* tooltip */                  N_("Use the normal view size"),
                                  G_CALLBACK (action_zoom_normal_callback) },
-  /* name, stock id */         { "Connect to Server", NULL, 
+  /* name, stock id */         { NAUTILUS_ACTION_CONNECT_TO_SERVER, NULL, 
   /* label, accelerator */       N_("Connect to _Server..."), NULL,
   /* tooltip */                  N_("Connect to a remote computer or shared disk"),
                                  G_CALLBACK (action_connect_to_server_callback) },
@@ -1014,13 +884,13 @@ static const GtkActionEntry main_entries[] = {
   /* name, stock id, label */  { "Go", NULL, N_("_Go") },
   /* name, stock id, label */  { "Bookmarks", NULL, N_("_Bookmarks") },
   /* name, stock id, label */  { "Tabs", NULL, N_("_Tabs") },
-  /* name, stock id, label */  { "New Window", "window-new", N_("New _Window"),
+  /* name, stock id, label */  { NAUTILUS_ACTION_NEW_WINDOW, "window-new", N_("New _Window"),
                                  "<control>N", N_("Open another Nautilus window for the displayed location"),
                                  G_CALLBACK (action_new_window_callback) },
   /* name, stock id, label */  { "New Tab", "tab-new", N_("New _Tab"),
                                  "<control>T", N_("Open another tab for the displayed location"),
                                  G_CALLBACK (action_new_tab_callback) },
-  /* name, stock id, label */  { "Close All Windows", NULL, N_("Close _All Windows"),
+  /* name, stock id, label */  { NAUTILUS_ACTION_CLOSE_ALL_WINDOWS, NULL, N_("Close _All Windows"),
                                  "<control>Q", N_("Close all Navigation windows"),
                                  G_CALLBACK (action_close_all_windows_callback) },
   /* name, stock id, label */  { NAUTILUS_ACTION_BACK, GTK_STOCK_GO_BACK, N_("_Back"),
@@ -1101,6 +971,18 @@ static const GtkRadioActionEntry main_radio_entries[] = {
 	  SIDEBAR_TREE }
 };
 
+static const gchar* app_actions[] = {
+	NAUTILUS_ACTION_NEW_WINDOW,
+	NAUTILUS_ACTION_CONNECT_TO_SERVER,
+	NAUTILUS_ACTION_PREFERENCES,
+	NAUTILUS_ACTION_HELP,
+	NAUTILUS_ACTION_ABOUT,
+	NAUTILUS_ACTION_CLOSE_ALL_WINDOWS,
+
+	/* also hide the help menu entirely when using an app menu */
+	"Help"
+};
+
 GtkActionGroup *
 nautilus_window_create_toolbar_action_group (NautilusWindow *window)
 {
@@ -1217,6 +1099,28 @@ nautilus_window_initialize_actions (NautilusWindow *window)
 			  NULL);
 }
 
+static void
+nautilus_window_menus_set_visibility_for_app_menu (NautilusWindow *window)
+{
+	const gchar *action_name;
+	gboolean shows_app_menu;
+	GtkSettings *settings;
+	GtkAction *action;
+	gint idx;
+
+	settings = gtk_settings_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (window)));
+	g_object_get (settings,
+		      "gtk-shell-shows-app-menu", &shows_app_menu,
+		      NULL);
+
+	for (idx = 0; idx < G_N_ELEMENTS (app_actions); idx++) {
+		action_name = app_actions[idx];
+		action = gtk_action_group_get_action (window->details->main_action_group, action_name);
+
+		gtk_action_set_visible (action, !shows_app_menu);
+	}
+}
+
 /**
  * nautilus_window_initialize_menus
  * 
@@ -1249,6 +1153,11 @@ nautilus_window_initialize_menus (NautilusWindow *window)
 					    0, G_CALLBACK (sidebar_radio_entry_changed_cb),
 					    window);
 
+	nautilus_window_menus_set_visibility_for_app_menu (window);
+	g_signal_connect_swapped (gtk_settings_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (window))),
+				  "notify::gtk-shell-shows-app-menu",
+				  G_CALLBACK (nautilus_window_menus_set_visibility_for_app_menu), window);
+
 	action = gtk_action_group_get_action (action_group, NAUTILUS_ACTION_UP);
 	g_object_set (action, "short_label", _("_Up"), NULL);
 
