@@ -179,7 +179,7 @@ search_bar_activate_callback (NautilusSearchBar *bar,
 		g_object_unref (query);
 	}
 
-	nautilus_window_slot_go_to (pane->active_slot, location, FALSE);
+	nautilus_window_slot_open_location (pane->active_slot, location, 0);
 
 	nautilus_directory_unref (directory);
 	g_object_unref (location);	
@@ -269,20 +269,27 @@ nautilus_window_pane_hide_search_bar (NautilusWindowPane *pane)
 
 static void
 navigation_bar_location_changed_callback (GtkWidget *widget,
-					  const char *uri,
+					  GFile *location,
 					  NautilusWindowPane *pane)
 {
-	GFile *location;
-
 	nautilus_toolbar_set_show_location_entry (NAUTILUS_TOOLBAR (pane->tool_bar), FALSE);
 	nautilus_window_pane_hide_search_bar (pane);
 	nautilus_window_pane_hide_temporary_bars (pane);
 
 	restore_focus_widget (pane);
 
-	location = g_file_new_for_uri (uri);
-	nautilus_window_slot_go_to (pane->active_slot, location, FALSE);
-	g_object_unref (location);
+	nautilus_window_slot_open_location (pane->active_slot, location, 0);
+}
+
+static gboolean
+toolbar_focus_in_callback (GtkWidget *widget,
+			   GdkEventFocus *event,
+			   gpointer user_data)
+{
+	NautilusWindowPane *pane = user_data;
+	nautilus_window_set_active_pane (pane->window, pane);
+
+	return FALSE;
 }
 
 static void
@@ -294,68 +301,32 @@ path_bar_location_changed_callback (GtkWidget *widget,
 	int i;
 
 	slot = pane->active_slot;
+	nautilus_window_set_active_pane (pane->window, pane);
 
 	/* check whether we already visited the target location */
 	i = bookmark_list_get_uri_index (slot->back_list, location);
 	if (i >= 0) {
-		nautilus_window_back_or_forward (pane->window, TRUE, i, FALSE);
+		nautilus_window_back_or_forward (pane->window, TRUE, i, 0);
 	} else {
-		nautilus_window_slot_go_to (pane->active_slot, location, FALSE);
+		nautilus_window_slot_open_location (pane->active_slot, location, 0);
 	}
 }
 
-static gboolean
-path_bar_button_pressed_callback (GtkWidget *widget,
-				  GdkEventButton *event,
-				  NautilusWindowPane *pane)
-{
-	NautilusWindowSlot *slot;
-	NautilusView *view;
-	GFile *location;
-	char *uri;
-
-	g_object_set_data (G_OBJECT (widget), "handle-button-release",
-			   GINT_TO_POINTER (TRUE));
-
-	if (event->button == 3) {
-		slot = nautilus_window_get_active_slot (pane->window);
-		view = slot->content_view;
-		if (view != NULL) {
-			location = nautilus_path_bar_get_path_for_button (
-				NAUTILUS_PATH_BAR (pane->path_bar), widget);
-			if (location != NULL) {
-				uri = g_file_get_uri (location);
-				nautilus_view_pop_up_location_context_menu (
-					view, event, uri);
-				g_object_unref (location);
-				g_free (uri);
-				return TRUE;
-			}
-		}
-	}
-
-	return FALSE;
-}
-
-static gboolean
-path_bar_button_released_callback (GtkWidget *widget,
-				   GdkEventButton *event,
-				   NautilusWindowPane *pane)
+static void
+path_bar_path_event_callback (NautilusPathBar *path_bar,
+			      GFile *location,
+			      GdkEventButton *event,
+			      NautilusWindowPane *pane)
 {
 	NautilusWindowSlot *slot;
 	NautilusWindowOpenFlags flags;
-	GFile *location;
 	int mask;
-	gboolean handle_button_release;
+	NautilusView *view;
+	char *uri;
 
-	mask = event->state & gtk_accelerator_get_default_mod_mask ();
-	flags = 0;
-
-	handle_button_release = GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (widget),
-						  "handle-button-release"));
-
-	if (event->type == GDK_BUTTON_RELEASE && handle_button_release) {
-		location = nautilus_path_bar_get_path_for_button (NAUTILUS_PATH_BAR (pane->path_bar), widget);
+	if (event->type == GDK_BUTTON_RELEASE) {
+		mask = event->state & gtk_accelerator_get_default_mod_mask ();
+		flags = 0;
 
 		if (event->button == 2 && mask == 0) {
 			flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
@@ -365,25 +336,17 @@ path_bar_button_released_callback (GtkWidget *widget,
 
 		if (flags != 0) {
 			slot = nautilus_window_get_active_slot (pane->window);
-			nautilus_window_slot_open_location (slot, location,
-							    flags, NULL);
-			g_object_unref (location);
-			return TRUE;
+			nautilus_window_slot_open_location (slot, location, flags);
+		}
+	} else if (event->button == 3) {
+		slot = nautilus_window_get_active_slot (pane->window);
+		view = slot->content_view;
+		if (view != NULL) {
+			uri = g_file_get_uri (location);
+			nautilus_view_pop_up_location_context_menu (view, event, uri);
+			g_free (uri);
 		}
-
-		g_object_unref (location);
 	}
-
-	return FALSE;
-}
-
-static void
-path_bar_button_drag_begin_callback (GtkWidget *widget,
-				     GdkEventButton *event,
-				     gpointer user_data)
-{
-	g_object_set_data (G_OBJECT (widget), "handle-button-release",
-			   GINT_TO_POINTER (FALSE));
 }
 
 static void
@@ -396,43 +359,6 @@ notebook_popup_menu_new_tab_cb (GtkMenuItem *menuitem,
 	nautilus_window_new_tab (pane->window);
 }
 
-static void
-path_bar_path_set_callback (GtkWidget *widget,
-			    GFile *location,
-			    NautilusWindowPane *pane)
-{
-	GList *children, *l;
-	GtkWidget *child;
-
-	children = gtk_container_get_children (GTK_CONTAINER (widget));
-
-	for (l = children; l != NULL; l = l->next) {
-		child = GTK_WIDGET (l->data);
-
-		if (!GTK_IS_TOGGLE_BUTTON (child)) {
-			continue;
-		}
-
-		if (!g_signal_handler_find (child,
-					    G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA,
-					    0, 0, NULL,
-					    path_bar_button_pressed_callback,
-					    pane)) {
-			g_signal_connect (child, "button-press-event",
-					  G_CALLBACK (path_bar_button_pressed_callback),
-					  pane);
-			g_signal_connect (child, "button-release-event",
-					  G_CALLBACK (path_bar_button_released_callback),
-					  pane);
-			g_signal_connect (child, "drag-begin",
-					  G_CALLBACK (path_bar_button_drag_begin_callback),
-					  pane);
-		}
-	}
-
-	g_list_free (children);
-}
-
 static void
 notebook_popup_menu_move_left_cb (GtkMenuItem *menuitem,
 				  gpointer user_data)
@@ -597,21 +523,6 @@ notebook_switch_page_cb (GtkNotebook *notebook,
 	return FALSE;
 }
 
-static void
-real_set_active (NautilusWindowPane *pane,
-		 gboolean is_active)
-{
-	NautilusNavigationState *nav_state;
-
-	if (is_active) {
-		nav_state = nautilus_window_get_navigation_state (pane->window);
-		nautilus_navigation_state_set_master (nav_state, pane->action_group);
-	}
-
-	/* toolbar */
-	gtk_widget_set_sensitive (pane->tool_bar, is_active);
-}
-
 static void
 action_show_hide_search_callback (GtkAction *action,
 				  gpointer user_data)
@@ -665,6 +576,15 @@ setup_search_action (NautilusWindowPane *pane)
 			  G_CALLBACK (action_show_hide_search_callback), pane);
 }
 
+static void
+toolbar_action_group_activated_callback (GtkActionGroup *action_group,
+					 GtkAction *action,
+					 gpointer user_data)
+{
+	NautilusWindowPane *pane = user_data;
+	nautilus_window_set_active_pane (pane->window, pane);
+}
+
 static void
 nautilus_window_pane_set_property (GObject *object,
 				   guint arg_id,
@@ -737,11 +657,16 @@ nautilus_window_pane_constructed (GObject *obj)
 	pane->action_group = action_group;
 
 	setup_search_action (pane);
+	g_signal_connect (pane->action_group, "pre-activate",
+			  G_CALLBACK (toolbar_action_group_activated_callback), pane);
 
 	gtk_box_pack_start (GTK_BOX (pane),
 			    pane->tool_bar,
 			    FALSE, FALSE, 0);
 
+	/* start as non-active */
+	nautilus_window_pane_set_active (pane, FALSE);
+
 	g_settings_bind_with_mapping (nautilus_window_state,
 				      NAUTILUS_WINDOW_STATE_START_WITH_TOOLBAR,
 				      pane->tool_bar,
@@ -756,8 +681,8 @@ nautilus_window_pane_constructed (GObject *obj)
 
 	g_signal_connect_object (pane->path_bar, "path-clicked",
 				 G_CALLBACK (path_bar_location_changed_callback), pane, 0);
-	g_signal_connect_object (pane->path_bar, "path-set",
-				 G_CALLBACK (path_bar_path_set_callback), pane, 0);
+	g_signal_connect_object (pane->path_bar, "path-event",
+				 G_CALLBACK (path_bar_path_event_callback), pane, 0);
 
 	/* connect to the location bar signals */
 	pane->location_bar = nautilus_toolbar_get_location_bar (NAUTILUS_TOOLBAR (pane->tool_bar));
@@ -772,6 +697,8 @@ nautilus_window_pane_constructed (GObject *obj)
 				 G_CALLBACK (navigation_bar_location_changed_callback), pane, 0);
 	g_signal_connect_object (pane->location_bar, "cancel",
 				 G_CALLBACK (navigation_bar_cancel_callback), pane, 0);
+	g_signal_connect_object (nautilus_location_bar_get_entry (NAUTILUS_LOCATION_BAR (pane->location_bar)), "focus-in-event",
+				 G_CALLBACK (toolbar_focus_in_callback), pane, 0);
 
 	/* connect to the search bar signals */
 	pane->search_bar = nautilus_toolbar_get_search_bar (NAUTILUS_TOOLBAR (pane->tool_bar));
@@ -781,6 +708,8 @@ nautilus_window_pane_constructed (GObject *obj)
 				 G_CALLBACK (search_bar_activate_callback), pane, 0);
 	g_signal_connect_object (pane->search_bar, "cancel",
 				 G_CALLBACK (search_bar_cancel_callback), pane, 0);
+	g_signal_connect_object (nautilus_search_bar_get_entry (NAUTILUS_SEARCH_BAR (pane->search_bar)), "focus-in-event",
+				 G_CALLBACK (toolbar_focus_in_callback), pane, 0);
 
 	/* initialize the notebook */
 	pane->notebook = g_object_new (NAUTILUS_TYPE_NOTEBOOK, NULL);
@@ -807,9 +736,6 @@ nautilus_window_pane_constructed (GObject *obj)
 	gtk_widget_show (pane->notebook);
 	gtk_container_set_border_width (GTK_CONTAINER (pane->notebook), 0);
 
-	/* start as non-active */
-	real_set_active (pane, FALSE);
-
 	/* Ensure that the view has some minimal size and that other parts
 	 * of the UI (like location bar and tabs) don't request more and
 	 * thus affect the default position of the split view paned.
@@ -847,7 +773,6 @@ nautilus_window_pane_init (NautilusWindowPane *pane)
 {
 	pane->slots = NULL;
 	pane->active_slot = NULL;
-	pane->is_active = FALSE;
 
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (pane), GTK_ORIENTATION_VERTICAL);
 }
@@ -860,25 +785,42 @@ nautilus_window_pane_new (NautilusWindow *window)
 			     NULL);
 }
 
+static void
+nautilus_window_pane_set_active_style (NautilusWindowPane *pane,
+				       gboolean is_active)
+{
+	GtkStyleContext *style;
+	gboolean has_inactive;
+
+	style = gtk_widget_get_style_context (GTK_WIDGET (pane));
+	has_inactive = gtk_style_context_has_class (style, "nautilus-inactive-pane");
+
+	if (has_inactive == !is_active) {
+		return;
+	}
+
+	if (is_active) {
+		gtk_style_context_remove_class (style, "nautilus-inactive-pane");
+	} else {
+		gtk_style_context_add_class (style, "nautilus-inactive-pane");
+	}
+
+	gtk_widget_reset_style (GTK_WIDGET (pane));
+}
+
 void
 nautilus_window_pane_set_active (NautilusWindowPane *pane,
 				 gboolean is_active)
 {
-	NautilusView *view;
+	NautilusNavigationState *nav_state;
 
-	if (is_active == pane->is_active) {
-		return;
+	if (is_active) {
+		nav_state = nautilus_window_get_navigation_state (pane->window);
+		nautilus_navigation_state_set_master (nav_state, pane->action_group);
 	}
 
-	pane->is_active = is_active;
-
-	/* notify the current view about its activity state */
-	if (pane->active_slot != NULL) {
-		view = nautilus_window_slot_get_current_view (pane->active_slot);
-		nautilus_view_set_is_active (view, is_active);
-	}
-
-	real_set_active (pane, is_active);
+	/* pane inactive style */
+	nautilus_window_pane_set_active_style (pane, is_active);
 }
 
 void
