@@ -115,6 +115,9 @@ real_update_query_editor (NautilusWindowSlot *slot)
 		nautilus_window_slot_add_extra_location_widget (slot, query_editor);
 		gtk_widget_show (query_editor);
 		nautilus_query_editor_grab_focus (NAUTILUS_QUERY_EDITOR (query_editor));
+
+		g_object_add_weak_pointer (G_OBJECT (slot->query_editor),
+					   (gpointer *) &slot->query_editor);
 	}
 
 	nautilus_directory_unref (directory);
@@ -136,7 +139,7 @@ real_active (NautilusWindowSlot *slot)
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (pane->notebook), page_num);
 
 	/* sync window to new slot */
-	nautilus_window_sync_status (window);
+	nautilus_window_push_status (window, slot->status_text);
 	nautilus_window_sync_allow_stop (window, slot);
 	nautilus_window_sync_title (window, slot);
 	nautilus_window_sync_zoom_widgets (window);
@@ -501,7 +504,6 @@ set_status_data_free (gpointer data)
 	SetStatusData *status_data = data;
 
 	g_free (status_data->status);
-	g_object_unref (status_data->slot);
 
 	g_slice_free (SetStatusData, data);
 }
@@ -537,7 +539,7 @@ set_floating_bar_status (NautilusWindowSlot *slot,
 
 	status_data = g_slice_new0 (SetStatusData);
 	status_data->status = g_strdup (status);
-	status_data->slot = g_object_ref (slot);
+	status_data->slot = slot;
 
 	/* waiting for half of the double-click-time before setting
 	 * the status seems to be a good approximation of not setting it
@@ -569,7 +571,7 @@ nautilus_window_slot_set_status (NautilusWindowSlot *slot,
 
 	window = nautilus_window_slot_get_window (slot);
 	if (slot == nautilus_window_get_active_slot (window)) {
-		nautilus_window_sync_status (window);
+		nautilus_window_push_status (window, slot->status_text);
 	}
 }
 
@@ -589,8 +591,6 @@ nautilus_window_slot_update_query_editor (NautilusWindowSlot *slot)
 	}
 
 	real_update_query_editor (slot);
-
-	eel_add_weak_pointer (&slot->query_editor);
 }
 
 static void
@@ -651,32 +651,22 @@ nautilus_window_slot_get_current_view (NautilusWindowSlot *slot)
 
 void
 nautilus_window_slot_go_home (NautilusWindowSlot *slot,
-			      gboolean new_tab)
+			      NautilusWindowOpenFlags flags)
 {			      
 	GFile *home;
-	NautilusWindowOpenFlags flags;
 
 	g_return_if_fail (NAUTILUS_IS_WINDOW_SLOT (slot));
 
-	if (new_tab) {
-		flags = NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
-	} else {
-		flags = 0;
-	}
-
 	home = g_file_new_for_path (g_get_home_dir ());
-	nautilus_window_slot_open_location_full (slot, home, 
-						 flags, NULL, NULL, NULL);
+	nautilus_window_slot_open_location (slot, home, flags);
 	g_object_unref (home);
 }
 
 void
 nautilus_window_slot_go_up (NautilusWindowSlot *slot,
-			    gboolean close_behind,
-			    gboolean new_tab)
+			    NautilusWindowOpenFlags flags)
 {
 	GFile *parent;
-	NautilusWindowOpenFlags flags;
 
 	if (slot->location == NULL) {
 		return;
@@ -687,18 +677,7 @@ nautilus_window_slot_go_up (NautilusWindowSlot *slot,
 		return;
 	}
 
-	flags = 0;
-	if (close_behind) {
-		flags |= NAUTILUS_WINDOW_OPEN_FLAG_CLOSE_BEHIND;
-	}
-	if (new_tab) {
-		flags |= NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
-	}
-
-	nautilus_window_slot_open_location (slot, parent,
-					    flags,
-					    NULL);
-
+	nautilus_window_slot_open_location (slot, parent, flags);
 	g_object_unref (parent);
 }
 
