@@ -32,7 +32,6 @@
 #include "nautilus-window-private.h"
 
 #include "nautilus-actions.h"
-#include "nautilus-application.h"
 #include "nautilus-bookmarks-window.h"
 #include "nautilus-location-bar.h"
 #include "nautilus-mime-actions.h"
@@ -61,7 +60,6 @@
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-clipboard.h>
-#include <libnautilus-private/nautilus-undo.h>
 #include <libnautilus-private/nautilus-search-directory.h>
 #include <libnautilus-private/nautilus-signaller.h>
 
@@ -123,7 +121,7 @@ static void cancel_view_as_callback         (NautilusWindowSlot      *slot);
 static void action_view_as_callback         (GtkAction               *action,
 					     ActivateViewData        *data);
 
-G_DEFINE_TYPE (NautilusWindow, nautilus_window, GTK_TYPE_WINDOW);
+G_DEFINE_TYPE (NautilusWindow, nautilus_window, GTK_TYPE_APPLICATION_WINDOW);
 
 static const struct {
 	unsigned int keyval;
@@ -162,22 +160,13 @@ nautilus_window_push_status (NautilusWindow *window,
 	}
 }
 
-void
-nautilus_window_sync_status (NautilusWindow *window)
-{
-	NautilusWindowSlot *slot;
-
-	slot = nautilus_window_get_active_slot (window);
-	nautilus_window_push_status (window, slot->status_text);
-}
-
 void
 nautilus_window_go_to (NautilusWindow *window, GFile *location)
 {
 	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
-	nautilus_window_slot_go_to (nautilus_window_get_active_slot (window),
-				    location, FALSE);
+	nautilus_window_slot_open_location (nautilus_window_get_active_slot (window),
+					    location, 0);
 }
 
 void
@@ -188,17 +177,14 @@ nautilus_window_go_to_full (NautilusWindow *window,
 {
 	g_return_if_fail (NAUTILUS_IS_WINDOW (window));
 
-	nautilus_window_slot_go_to_full (nautilus_window_get_active_slot (window),
-					 location, FALSE, callback, user_data);
+	nautilus_window_slot_open_location_full (nautilus_window_get_active_slot (window),
+						 location, 0, NULL, callback, user_data);
 }
 
-static gboolean
-nautilus_window_go_up_signal (NautilusWindow *window, gboolean close_behind)
+static void
+nautilus_window_go_up_signal (NautilusWindow *window)
 {
-	nautilus_window_slot_go_up (nautilus_window_get_active_slot (window),
-				    close_behind, FALSE);
-
-	return TRUE;
+	nautilus_window_slot_go_up (nautilus_window_get_active_slot (window), 0);
 }
 
 void
@@ -231,7 +217,7 @@ nautilus_window_new_tab (NautilusWindow *window)
 
 		new_slot = nautilus_window_pane_open_slot (current_slot->pane, flags);
 		nautilus_window_set_active_slot (window, new_slot);
-		nautilus_window_slot_go_to (new_slot, location, FALSE);
+		nautilus_window_slot_open_location (new_slot, location, 0);
 		g_object_unref (location);
 	}
 }
@@ -537,13 +523,16 @@ nautilus_window_constructed (GObject *self)
 	GtkWidget *vbox;
 	NautilusWindowPane *pane;
 	NautilusWindowSlot *slot;
-	NautilusApplication *application;
 
 	window = NAUTILUS_WINDOW (self);
-	application = nautilus_application_get_singleton ();
 
 	G_OBJECT_CLASS (nautilus_window_parent_class)->constructed (self);
 
+	/* disable automatic menubar handling, since we show our regular
+	 * menubar together with the app menu.
+	 */
+	gtk_application_window_set_show_menubar (GTK_APPLICATION_WINDOW (self), FALSE);
+
 	grid = gtk_grid_new ();
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (grid), GTK_ORIENTATION_VERTICAL);
 	gtk_widget_show (grid);
@@ -613,7 +602,6 @@ nautilus_window_constructed (GObject *self)
 
 	nautilus_window_initialize_bookmarks_menu (window);
 	nautilus_window_set_initial_window_geometry (window);
-	nautilus_undo_manager_attach (application->undo_manager, G_OBJECT (window));
 
 	slot = nautilus_window_pane_open_slot (window->details->active_pane, 0);
 	nautilus_window_set_active_slot (window, slot);
@@ -993,6 +981,7 @@ nautilus_window_key_press_event (GtkWidget *widget,
 	NautilusWindow *window;
 	NautilusWindowSlot *active_slot;
 	NautilusView *view;
+	GtkWidget *focus_widget;
 	int i;
 
 	window = NAUTILUS_WINDOW (widget);
@@ -1011,6 +1000,17 @@ nautilus_window_key_press_event (GtkWidget *widget,
 		}
 	}
 
+	focus_widget = gtk_window_get_focus (GTK_WINDOW (window));
+	if (view != NULL && focus_widget != NULL &&
+	    GTK_IS_EDITABLE (focus_widget)) {
+		/* if we have input focus on a GtkEditable (e.g. a GtkEntry), forward
+		 * the event to it before activating accelerator bindings too.
+		 */
+		if (gtk_window_propagate_key_event (GTK_WINDOW (window), event)) {
+			return TRUE;
+		}
+	}
+
 	for (i = 0; i < G_N_ELEMENTS (extra_window_keybindings); i++) {
 		if (extra_window_keybindings[i].keyval == event->keyval) {
 			const GList *action_groups;
@@ -1465,7 +1465,6 @@ nautilus_window_sync_zoom_widgets (NautilusWindow *window)
 		can_zoom_in = can_zoom && nautilus_view_can_zoom_in (view);
 		can_zoom_out = can_zoom && nautilus_view_can_zoom_out (view);
 	} else {
-		zoom_level = NAUTILUS_ZOOM_LEVEL_STANDARD;
 		supports_zooming = FALSE;
 		can_zoom = FALSE;
 		can_zoom_in = FALSE;
@@ -1808,16 +1807,12 @@ nautilus_window_state_event (GtkWidget *widget,
 	return FALSE;
 }
 
-static void
-nautilus_window_go_back (NautilusWindow *window)
+static gboolean
+nautilus_window_delete_event (GtkWidget *widget,
+			      GdkEventAny *event)
 {
-	nautilus_window_back_or_forward (window, TRUE, 0, FALSE);
-}
-
-static void
-nautilus_window_go_forward (NautilusWindow *window)
-{
-	nautilus_window_back_or_forward (window, FALSE, 0, FALSE);
+	nautilus_window_close (NAUTILUS_WINDOW (widget));
+	return FALSE;
 }
 
 static gboolean
@@ -1827,14 +1822,13 @@ nautilus_window_button_press_event (GtkWidget *widget,
 	NautilusWindow *window;
 	gboolean handled;
 
-	handled = FALSE;
 	window = NAUTILUS_WINDOW (widget);
 
 	if (mouse_extra_buttons && (event->button == mouse_back_button)) {
-		nautilus_window_go_back (window);
+		nautilus_window_back_or_forward (window, TRUE, 0, 0);
 		handled = TRUE; 
 	} else if (mouse_extra_buttons && (event->button == mouse_forward_button)) {
-		nautilus_window_go_forward (window);
+		nautilus_window_back_or_forward (window, FALSE, 0, 0);
 		handled = TRUE;
 	} else if (GTK_WIDGET_CLASS (nautilus_window_parent_class)->button_press_event) {
 		handled = GTK_WIDGET_CLASS (nautilus_window_parent_class)->button_press_event (widget, event);
@@ -1936,6 +1930,7 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	wclass->key_press_event = nautilus_window_key_press_event;
 	wclass->window_state_event = nautilus_window_state_event;
 	wclass->button_press_event = nautilus_window_button_press_event;
+	wclass->delete_event = nautilus_window_delete_event;
 
 	class->get_icon = real_get_icon;
 	class->close = real_window_close;
@@ -1949,13 +1944,13 @@ nautilus_window_class_init (NautilusWindowClass *class)
 				      G_PARAM_STATIC_STRINGS);
 
 	signals[GO_UP] =
-		g_signal_new ("go_up",
+		g_signal_new ("go-up",
 			      G_TYPE_FROM_CLASS (class),
 			      G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
 			      G_STRUCT_OFFSET (NautilusWindowClass, go_up),
-			      g_signal_accumulator_true_handled, NULL,
+			      NULL, NULL,
 			      g_cclosure_marshal_generic,
-			      G_TYPE_BOOLEAN, 1, G_TYPE_BOOLEAN);
+			      G_TYPE_NONE, 0);
 	signals[RELOAD] =
 		g_signal_new ("reload",
 			      G_TYPE_FROM_CLASS (class),
@@ -1992,8 +1987,7 @@ nautilus_window_class_init (NautilusWindowClass *class)
 
 	binding_set = gtk_binding_set_by_class (class);
 	gtk_binding_entry_add_signal (binding_set, GDK_KEY_BackSpace, 0,
-				      "go_up", 1,
-				      G_TYPE_BOOLEAN, FALSE);
+				      "go-up", 0);
 	gtk_binding_entry_add_signal (binding_set, GDK_KEY_F5, 0,
 				      "reload", 0);
 	gtk_binding_entry_add_signal (binding_set, GDK_KEY_slash, 0,
@@ -2023,6 +2017,16 @@ nautilus_window_class_init (NautilusWindowClass *class)
 	g_type_class_add_private (oclass, sizeof (NautilusWindowDetails));
 }
 
+NautilusWindow *
+nautilus_window_new (GtkApplication *application,
+		     GdkScreen      *screen)
+{
+	return g_object_new (NAUTILUS_TYPE_WINDOW,
+			     "application", application,
+			     "screen", screen,
+			     NULL);
+}
+
 void
 nautilus_window_split_view_on (NautilusWindow *window)
 {
@@ -2046,7 +2050,7 @@ nautilus_window_split_view_on (NautilusWindow *window)
 		location = g_file_new_for_path (g_get_home_dir ());
 	}
 
-	nautilus_window_slot_go_to (slot, location, FALSE);
+	nautilus_window_slot_open_location (slot, location, 0);
 	g_object_unref (location);
 
 	window_set_search_action_text (window, FALSE);
@@ -2082,3 +2086,126 @@ nautilus_window_split_view_showing (NautilusWindow *window)
 {
 	return g_list_length (NAUTILUS_WINDOW (window)->details->panes) > 1;
 }
+
+NautilusWindowOpenFlags
+nautilus_event_get_window_open_flags (void)
+{
+	NautilusWindowOpenFlags flags = 0;
+	GdkEvent *event;
+
+	event = gtk_get_current_event ();
+
+	if (event == NULL) {
+		return flags;
+	}
+
+	if ((event->type == GDK_BUTTON_PRESS || event->type == GDK_BUTTON_RELEASE) &&
+	    (event->button.button == 2)) {
+		flags |= NAUTILUS_WINDOW_OPEN_FLAG_NEW_TAB;
+	}
+
+	gdk_event_free (event);
+
+	return flags;
+}
+
+void
+nautilus_window_show_about_dialog (NautilusWindow *window)
+{
+	const gchar *authors[] = {
+		"Alexander Larsson",
+		"Ali Abdin",
+		"Anders Carlsson",
+		"Andrew Walton",
+		"Andy Hertzfeld",
+		"Arlo Rose",
+		"Christian Neumair",
+		"Cosimo Cecchi",
+		"Darin Adler",
+		"David Camp",
+		"Eli Goldberg",
+		"Elliot Lee",
+		"Eskil Heyn Olsen",
+		"Ettore Perazzoli",
+		"Gene Z. Ragan",
+		"George Lebl",
+		"Ian McKellar",
+		"J Shane Culpepper",
+		"James Willcox",
+		"Jan Arne Petersen",
+		"John Harper",
+		"John Sullivan",
+		"Josh Barrow",
+		"Maciej Stachowiak",
+		"Mark McLoughlin",
+		"Mathieu Lacage",
+		"Mike Engber",
+		"Mike Fleming",
+		"Pavel Cisler",
+		"Ramiro Estrugo",
+		"Raph Levien",
+		"Rebecca Schulman",
+		"Robey Pointer",
+		"Robin * Slomkowski",
+		"Seth Nickell",
+		"Susan Kare",
+		"Tomas Bzatek",
+		NULL
+	};
+	const gchar *documenters[] = {
+		"GNOME Documentation Team",
+		"Sun Microsystems",
+		NULL
+	};
+	const gchar *license[] = {
+		N_("Nautilus is free software; you can redistribute it and/or modify "
+		   "it under the terms of the GNU General Public License as published by "
+		   "the Free Software Foundation; either version 2 of the License, or "
+		   "(at your option) any later version."),
+		N_("Nautilus is distributed in the hope that it will be useful, "
+		   "but WITHOUT ANY WARRANTY; without even the implied warranty of "
+		   "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
+		   "GNU General Public License for more details."),
+		N_("You should have received a copy of the GNU General Public License "
+		   "along with Nautilus; if not, write to the Free Software Foundation, Inc., "
+		   "51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA")
+	};
+	gchar *license_trans, *copyright_str;
+	GDateTime *date;
+
+	license_trans = g_strjoin ("\n\n", _(license[0]), _(license[1]),
+					     _(license[2]), NULL);
+
+	date = g_date_time_new_now_local ();
+
+	/* Translators: these two strings here indicate the copyright time span,
+	 * e.g. 1999-2011.
+	 */
+	copyright_str = g_strdup_printf (_("Copyright \xC2\xA9 %Id\xE2\x80\x93%Id "
+					   "The Nautilus authors"), 1999, g_date_time_get_year (date));
+
+	gtk_show_about_dialog (window ? GTK_WINDOW (window) : NULL,
+			       "program-name", _("Nautilus"),
+			       "version", VERSION,
+			       "comments", _("Nautilus lets you organize "
+					     "files and folders, both on "
+					     "your computer and online."),
+			       "copyright", copyright_str,
+			       "license", license_trans,
+			       "wrap-license", TRUE,
+			       "authors", authors,
+			       "documenters", documenters,
+				/* Translators should localize the following string
+				 * which will be displayed at the bottom of the about
+				 * box to give credit to the translator(s).
+				 */
+			      "translator-credits", _("translator-credits"),
+			      "logo-icon-name", "nautilus",
+			      "website", "http://live.gnome.org/Nautilus",
+			      "website-label", _("Nautilus Web Site"),
+			      NULL);
+
+	g_free (license_trans);
+	g_free (copyright_str);
+	g_date_time_unref (date);
+}
